<?php
namespace PME\Controllers\Expedicao;

use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class ControleExpedicaoController extends \Zeedhi\Framework\Controller\Report {

    protected $entityManager;
    protected $environment;
    protected $birtStrategy;
    protected $newCode;
    protected $connection;

    public function __construct(ReportService $reportService, $entityManager, $environment, $birtStrategy, $newCode, $connection) {
      $this->entityManager = $entityManager;
      $this->environment = $environment;
      $this->birtStrategy  = $birtStrategy;
      $this->newCode       = $newCode;
      $this->connection    = $connection;

      parent::__construct($reportService);
    }

    protected $reportMapping = array (
      'PME02800' => array (
        'strategy' => 'BIRT',
        'parameterMapping' => array (
          "CDFILCENTPME"  => "P_CDFILCENTPME",
          "NMFILCENTPME"  => "P_NMFILCENTPME",
          "SERVICO"       => "P_CDSERVFILI",
          "UNIDADE"       => "P_CDFILIAL",
          "CDOPERADOR"    => "P_CDOPERADOR",
          "NMOPERADOR"    => "P_NMOPERADOR",
          "DTDE"          => "P_DTINICIAL",
          "DTATE"         => "P_DTFINAL",
          "NRLISTA"       => "P_NRLISTA",
          "CDPICTPROD"    => "P_CDPICTPROD",
          "TAMNIV"        => "P_TAMNIV",
          "CDARVPRODINI"  => "P_PRODINI",
          "CDARVPRODFIN"  => "P_PRODFIN",
          "NRORG"         => "P_NRORG",
          "IDTPREQPROD"   => "P_IDTPREQPROD"
        )
      ),
    );
    
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
      try{
        $row = $request->getRow();
        $nrorg = $this->environment->getNrOrg();
        
        if ($row['IDENT_PREPARACAO']) $row['IDTPREQPROD'] = 'P';
        
        if(empty($row['CDARVPRODINI'])) $row['CDARVPRODINI'] = 0;
  
        if(empty($row['CDARVPRODFIN'])) $row['CDARVPRODFIN'] = "ZZZZZZZZZZ";
        else $row['CDARVPRODFIN'] = str_pad($row['CDARVPRODFIN'], 10, "Z", STR_PAD_RIGHT);
        
        if (!\Zeedhi\Framework\Util\Functions::arrayKeyExists('ACRESCIMO', $row)) $row['ACRESCIMO'] = 0;

        $row['CDOPERADOR'] = $this->environment->getCdOperador(); 
        $row['NMOPERADOR'] = $this->environment->getCurrentUserName(); 

        if($row['UNIDADE'] === null) $row['UNIDADE'] = 'T';

        if(empty($row['SERVICO']) && empty($row['GRUPSERV'])){
          $row['SERVICO'] = 'T';
        } else if (empty($row['SERVICO']) && !empty($row['GRUPSERV'])) {
          $row['SERVICO'] = $this->getServicosGrupo($row);
        } else if(is_array($row['SERVICO'])){
          $row['SERVICO'] = join("_", $row['SERVICO']);
        }
      
        if($row['TIPOCARD'] === null) {
          $row['NRLISTA'] = $this->geraListaTipoCard($row);
        } else {
          $tipoCard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
          $row['NRLISTA'] = $this->geraListaTipoCard($row);
        }
        
        $row['NRORG'] = $nrorg;

        $this->birtStrategy->setReportFormat(strtolower($row['reportFormat']));
      } catch(\Exception $e) {
        $response->setError(new DTO\Response\Error($e->getMessage(), 1));
      }
    }
    
    private function geraListaTipoCard($row) {
      if(empty($row['TIPOCARD'])) $cdtipocard = 'T';
      else $cdtipocard = is_array($row['TIPOCARD']) ? join("_", $row['TIPOCARD']) : $row['TIPOCARD'];
      
      $nrorg = $this->environment->getNrOrg();
      
      $nrlista = $this->newCode->getCodeByTableName('LISTA', $nrorg);
  
      $sql = "INSERT INTO LISTA (CDLISTA, NRLISTA, NRORG)
                SELECT CDTIPOCARD, :NRLISTA AS NRLISTA, NRORG FROM TIPOCARD WHERE CDFILCENTPME = :CDFILCENTPME AND (NRPASTATCARD = :NRPASTATCARD OR :NRPASTATCARD IS NULL) 
                AND ( INSTR(:CDTIPOCARD, CDTIPOCARD) <> 0 OR ( :CDTIPOCARD = 'T' ) )
                ORDER BY CDTIPOCARD";
      $stmt = $this->entityManager->getConnection()->prepare($sql);
      $stmt->execute(
        array(
          "NRLISTA"      => $nrlista,
          "CDFILCENTPME" => $row['CDFILCENTPME'],
          "CDTIPOCARD" => $cdtipocard,
          "NRPASTATCARD"     => null
        )
      );
    
      return $nrlista;
    }
    
    private function getServicosGrupo($rows) {
      $nrorg = $this->environment->getNrOrg();
      $servicos = [];
      
      if(is_array($rows['GRUPSERV'])) $grupServ = join("_", $rows['GRUPSERV']);
      else $grupServ = $rows['GRUPSERV'];

      $query = "SELECT S.CDSERVFILI, S.NMSERVICO, S.NRORG 
                  FROM SERVICO S
                 WHERE ( ( INSTR(:CDGRUPSERV, S.CDGRUPSERV) <> 0 ) OR ( :CDGRUPSERV = 'T' ) ) 
                   AND ( S.CDFILIAL = :CDFILCENTPME ) AND S.IDTIPOSERV = 'M'
                 ORDER BY S.CDSERVFILI";
      
      $params = array(
        "CDFILCENTPME" => $rows["CDFILCENTPME"],
        "CDGRUPSERV"   => $rows['GRUPSERV']
      );
      $stmt = $this->connection->prepare($query);
  	  $stmt->execute($params);
      $result = $stmt->fetchAll();
      
      $servGrupo = [];
      foreach($result as $serv){
        array_push($servGrupo, $serv['CDSERVFILI']);
      }
      $resultado = join("_", $servGrupo);
      return $resultado;
    }
}