<?php
namespace PME\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class Utilities extends \PME\Services\TeknisaCrud {

  protected $environment;
  protected $connection;
  protected $newCode;
  protected $dataSourceManager;
  protected $session;

  public function __construct($crudService, $parameterBag, $environment, $connection, $newCode, $dataSourceManager, $session) {
    $this->environment = $environment;
    $this->connection = $connection;
    $this->newCode = $newCode;
    $this->dataSourceManager = $dataSourceManager;
    $this->session = $session;
    parent::__construct($crudService, $parameterBag);
  }
  
  public function getServicos($central, $unidade = 'T', $ativo = null){
    $conditions = [
      array(
        "columnName" => 'CDFILCENTPME',
        "operator"   => '=',
        "value"      => $central
      ),
      array(
        "columnName" => 'CDFILIAL',
        "operator"   => '=',
        "value"      => $unidade
      )
    ];
    
    if ($ativo) array_push($conditions, array("columnName" => 'IDTCARATFILI', "operator" => '=', "value" => $ativo));

    $dataSet = $this->crudService->getFilteredDataSet("servicoUnidCentral", $conditions);
    return $dataSet->getRows();
  }
  
  public function getServicosGrup($central, $unidade = 'T', $grupServ = 'T', $ativo = null){
    $conditions = [
      array(
        "columnName" => 'CDFILCENTPME',
        "operator"   => '=',
        "value"      => $central
      ),
      array(
        "columnName" => 'CDFILIAL',
        "operator"   => '=',
        "value"      => $unidade
      ),
      array(
        "columnName" => 'CDGRUPSERV',
        "operator"   => '=',
        "value"      => $grupServ
      )
    ];
    
    if ($ativo) array_push($conditions, array("columnName" => 'IDTCARATFILI', "operator" => '=', "value" => $ativo));

    $dataSet = $this->crudService->getFilteredDataSet("servicoUnidCentralGrup", $conditions);
    return $dataSet->getRows();
  }

  public function getUnidades($central, $idContrResc = null){
    $conditions = [
      array(
        "columnName" => 'CDFILCENTPME',
        "operator"   => '=',
        "value"      => $central
      )
    ];
    
    if ($idContrResc) array_push($conditions, array("columnName" => 'IDCNTRRESC', "operator" => '=', "value" => $idContrResc));
    
    $dataSet = $this->crudService->getFilteredDataSet("agregadaPorCentral", $conditions);  
    return $dataSet->getRows();
  }
  
  public function getUnidadesAgrup($central, $agrup){
    $conditions = [
      array(
        "columnName" => 'CDFILCENTPME',
        "operator"   => '=',
        "value"      => $central
      ),
      array(
        "columnName" => 'CDGRUPFILI',
        "operator"   => '=',
        "value"      => $agrup
      )
    ];
    
    $dataSet = $this->crudService->getFilteredDataSet("agregadaPorCentralAgrup", $conditions);  
    return $dataSet->getRows();
  }

  public function getTipoCard($central, $ativo = null){
    $conditions = [
      array(
        "columnName" => 'CDFILCENTPME',
        "operator"   => '=',
        "value"      => $central
      ),
      array(
        "columnName" => 'NRPASTATCARD',
        "operator"   => '=',
        "value"      => null
      )
    ];
    
    if ($ativo) array_push($conditions, array("columnName" => 'IDTPCARDATIV', "operator" => '=', "value" => $ativo));
    
    $dataSet = $this->crudService->getFilteredDataSet("tpCardapioPorCentral", $conditions);  
    return $dataSet->getRows();
  }
    
  public function getDistinctServicos($central, $unidades = null, $ativo = null){
    if(!empty($unidades)) {
      if(is_array($unidades)) $unidades = join("_", $unidades);
    }
    $rows = $this->getServicos($central, $unidades, $ativo);
    $servicos = [];
    foreach($rows as $item) {
      array_push($servicos, $item['CDSERVFILI']);
    }
    $servicos = array_unique($servicos);
    return $servicos;
  }
  
  public function getDistinctServicosGrup($central, $unidades = null, $grupServ = null, $ativo = null){
    if(!empty($unidades)) {
      if(is_array($unidades)) $unidades = join("_", $unidades);
    }
    $rows = $this->getServicosGrup($central, $unidades, $grupServ, $ativo);
    $servicos = [];
    foreach($rows as $item) {
      array_push($servicos, $item['CDSERVFILI']);
    }
    $servicos = array_unique($servicos);
    return $servicos;
  }

  public function getNutrientes ($cdfilial) {
    $sql = "SELECT
              NUT1.NMREDUZIDO AS NMREDUZIDO1,
              NUT1.SGUNIDADE  AS SG1,
              NUT1.CDNUTRIENTE AS CDNUTRIENTE1,
              NUT2.NMREDUZIDO AS NMREDUZIDO2,
              NUT2.SGUNIDADE  AS SG2,
              NUT2.CDNUTRIENTE AS CDNUTRIENTE2,
              NUT3.NMREDUZIDO AS NMREDUZIDO3,
              NUT3.SGUNIDADE  AS SG3,
              NUT3.CDNUTRIENTE AS CDNUTRIENTE3,
              NUT4.NMREDUZIDO AS NMREDUZIDO4,
              NUT4.SGUNIDADE  AS SG4,
              NUT4.CDNUTRIENTE AS CDNUTRIENTE4
          FROM
              PARAMPLANEJA
          LEFT JOIN NUTRIENTE NUT1 ON NUT1.CDNUTRIENTE = PARAMPLANEJA.CDNUTRRELAT1
          LEFT JOIN NUTRIENTE NUT2 ON NUT2.CDNUTRIENTE = PARAMPLANEJA.CDNUTRRELAT2
          LEFT JOIN NUTRIENTE NUT3 ON NUT3.CDNUTRIENTE = PARAMPLANEJA.CDNUTRRELAT3
          LEFT JOIN NUTRIENTE NUT4 ON NUT4.CDNUTRIENTE = PARAMPLANEJA.CDNUTRRELAT4
          WHERE PARAMPLANEJA.CDFILIAL = :P_CDFILCENTPME";
    $params = array(
        'P_CDFILCENTPME' => $cdfilial
    );

    try {
        return $this->connection->fetchAll($sql, $params);
    } catch (\Exception $e) {
        throw $e;
    }
  }

  public function callProcedureNutrCard($central, $cdfilial, $cdservfili, $nutrientes, $nrSeqNutr = '', $idndpcal, $dtIni, $dtFin, $cdtipocard) {
		$nrorg = $this->environment->getNrOrg();

		if ($nrSeqNutr === '') $nrSeqNutr = $this->newCode->getCodeByTableName('CALCNUTR'.$cdfilial, $nrorg);
		$procedureCons = new StoredProcedure($this->connection, 'NUTRIENTE_DO_CARDAPIO_PME');

		$procedureCons->addParam(new Param('P_CDFILCENTPME', Param::PARAM_INPUT, $central, 			Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_CDFILIAL',     Param::PARAM_INPUT, $cdfilial,     Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_CDSERVFILI',   Param::PARAM_INPUT, $cdservfili,   Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_NUTRIENTES',   Param::PARAM_INPUT, $nutrientes,   Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_NRSEQUNUTR',   Param::PARAM_INPUT, $nrSeqNutr,    Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_IDNDPCAL',     Param::PARAM_INPUT, $idndpcal,    	Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_DTINICIAL',    Param::PARAM_INPUT, $dtIni,        Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_DTFINAL',      Param::PARAM_INPUT, $dtFin,        Param::PARAM_TYPE_STR));
		$procedureCons->addParam(new Param('P_CDTIPOCARD',   Param::PARAM_INPUT, $cdtipocard,   Param::PARAM_TYPE_STR));
		$procedureCons->execute();
		
		return $nrSeqNutr;
  }
  
  public function consumoPlanPMe($cdfilcentpme, $cdtipocard, $filial, $servico, $initialDate, $finalDate, $idarquivo = 'T', $idprodutos = 'C',
                                 $idsepprato = 'P', $acrescimo = 0, $idarredond = 'N', $cdprodIni = '0', $cdprodFin = 'zzzzzzzzzz') {

    $consplan = $this->newCode->getCodeByTableName('CONSPLAN'.$cdfilcentpme, $this->environment->getNrOrg());
    
    if(empty($cdtipocard)) $cdtipocard = null;
    else $cdtipocard = is_array($cdtipocard) ? join("_", $cdtipocard) : $cdtipocard;

    if(empty($filial)) $filial = null;
    else $filial = is_array($filial) ? join("_", $filial) : $filial;

    if(empty($servico)) $servico = null;
    else $servico = is_array($servico) ? join("_", $servico) : $servico;
    

	  $procedureCons = new StoredProcedure($this->connection, 'CONSUMO_PLANEJADO_PME');
  	
	  $procedureCons->addParam(new Param('P_CDFILCENTPME',  Param::PARAM_INPUT, $cdfilcentpme,                        Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_CDTIPOCARD',    Param::PARAM_INPUT, $cdtipocard,                          Param::PARAM_TYPE_STR));
	  $procedureCons->addParam(new Param('P_CDFILIAL',      Param::PARAM_INPUT, $filial,                              Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_CDSERVFILI',    Param::PARAM_INPUT, $servico,                             Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_DTINICIAL',     Param::PARAM_INPUT, $initialDate,                         Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_DTFINAL',       Param::PARAM_INPUT, $finalDate,                           Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_IDARQUIVO',     Param::PARAM_INPUT, $idarquivo,                           Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_IDPRODUTOS',    Param::PARAM_INPUT, $idprodutos,                          Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_IDSEPPRATO',    Param::PARAM_INPUT, $idsepprato,                          Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_PEACRESCIMO',   Param::PARAM_INPUT, $acrescimo,                           Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_IDARREDOND',    Param::PARAM_INPUT, $idarredond,                          Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_NRCONSPLAN',    Param::PARAM_INPUT, $consplan,                            Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_CDPRODUTOINI',  Param::PARAM_INPUT, $cdprodIni,                           Param::PARAM_TYPE_STR));
  	$procedureCons->addParam(new Param('P_CDPRODUTOFIN',  Param::PARAM_INPUT, $cdprodFin,                           Param::PARAM_TYPE_STR));
    $procedureCons->addParam(new Param('P_CDOPERADOR',    Param::PARAM_INPUT, $this->environment->getCdOperador(),  Param::PARAM_TYPE_STR));
    $procedureCons->execute();
  	return $consplan;
  }
    
  public function retornaDataProcessamento(DTO\Request\Row $request, DTO\Response $response) {
    $cdfilial = $request->getRow();
    if (count($cdfilial) == 0) {
      $parameters = $request->getParameters();
      $cdfilial = $parameters['filial'];
    }
    $dataProcessamento = strlen($cdfilial[0]) == 1 ? $this->dataProcessamento($cdfilial) : $this->dataProcessamento($cdfilial[0]); 
    $row['CONSPRAT'] = empty($row['CONSPRAT']) ? 'N' : 'S';
    $response->addDataSet(new DataSet('processDate', array($this->truncDate($dataProcessamento))));
  }

  public function dataProcessamento($unidade) {
    $dataSet = $this->dataSourceManager->findBy(new FilterCriteria('paramgeral'), array());
    $rows = $dataSet->getRows();
    if ($unidade === NULL || $unidade === 'null') $dataProcessamento = '';
    else {
      if ($rows[0]['IDUTILDTPROC'] != 'S') $dataProcessamento = date('d/m/Y');
      else $dataProcessamento = $this->retornaDataProcPorFilial($unidade);
    }
    return $dataProcessamento;
  }

  public function retornaDataProcPorFilial($cdfilial) {
    $filterCriteria = new FilterCriteria('paramfilial');
    $filterCriteria->addCondition('CDFILIAL', $cdfilial);
    $dataSet = $this->dataSourceManager->findBy($filterCriteria);
    $rows = $dataSet->getRows();
    if (!empty($rows) && !empty($rows[0]) && $rows[0]['DTPROCESSA']) $dataProcessamento = $rows[0]['DTPROCESSA'];
    else $dataProcessamento = date('d/m/Y');

    return $this->truncDate($dataProcessamento);
  }

  private function truncDate($date) {
    $date = explode(' ', $date);
    return $date[0];
  }
  
  public function getLanguage() {
    return $this->session->has("LOGIN_LANGUAGE") && !empty($this->session->get("LOGIN_LANGUAGE")) ? strtolower($this->session->get("LOGIN_LANGUAGE")) : 'pt_br';
  }
  
  public function getNrOrg() {
    return $this->environment->getNrOrg();
  }
  
  public function checkParamPlaneja($cdfilial) {
    $sql = "SELECT P.CDFILIAL, F.NMFILIAL FROM FILIAL F 
              LEFT JOIN PARAMPLANEJA P ON P.CDFILIAL = F.CDFILIAL WHERE F.CDFILIAL = :CDFILIAL";
    $params = array(
        'CDFILIAL' => $cdfilial,
    );

    try {
        $result = $this->connection->fetchAssoc($sql, $params);
        
        if (!empty($result) && $result['CDFILIAL'] !== null) return true;
        else {
          return $cdfilial.' | '.$result['NMFILIAL'];
        }
    } catch (\Exception $e) {
        throw $e;
    }
  }
}