<?php
namespace PME\Modules\Planejamento\Prato;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;

class ReceitaController extends \PME\Services\TeknisaCrud {

	protected $crudService;
	protected $parameterBag;
	protected $entityManager;
	protected $connection;
	protected $environment;
  protected $newCode;
	protected $utilities;
	protected $dataSourceManager;
  
  public function __construct($crudService, $parameterBag, $entityManager, $connection, $environment, $newCode, $utilities, $dataSourceManager) {
    $this->entityManager = $entityManager;
    $this->connection    = $connection;
    $this->environment   = $environment;
    $this->newCode       = $newCode;
		$this->utilities     = $utilities;
		$this->dataSourceManager = $dataSourceManager;
    parent::__construct($crudService, $parameterBag);
	}
	
	protected $keysMapping = array(
    'QTPROD' => array(
      'SERVICO'     => 'QTPRODRECSER',
      'LOCAL'       => 'QTPRODRECLOC',
      'REGIAO'      => 'QTPRODRECREGIAO',
      'PADRAOQUALI' => 'QTPRODRECPADQ',
      'PADRAO'      => 'QTPRODPRAT',
      'TIPOCARD'    => 'QTPRODPRATTP'
    ),
    'VRPEFATCOC' => array(
      'SERVICO'     => 'VRPEFATCOCSE',
      'LOCAL'       => 'VRPEFATCOCLO',
      'REGIAO'      => 'VRPEFATCOCREGIAO',
      'PADRAOQUALI' => 'VRPEFATCOCPADQ',
      'PADRAO'      => 'VRPEFATCOCPR',
      'TIPOCARD'    => 'VRPEFATCOCPRTP'
    ),
    'VRPEFATCOR' => array(
      'SERVICO'     => 'VRPEFATCORSE',
      'LOCAL'       => 'VRPEFATCORLO',
      'REGIAO'      => 'VRPEFATCORREGIAO',
      'PADRAOQUALI' => 'VRPEFATCORPADQ',
      'PADRAO'      => 'VRPEFATCORPR',
      'TIPOCARD'    => 'VRPEFATCORPRTP'
    ),
    'QTBRUTA' => array(
      'SERVICO'     => 'QTBRUTASE',
      'LOCAL'       => 'QTBRUTALO',
      'REGIAO'      => '',
      'PADRAOQUALI' => '',
      'PADRAO'      => 'QTBRUTAPR',
      'TIPOCARD'    => 'QTBRUTAPRTP'
    ),
    'QTUNIDEST' => array(
      'SERVICO'     => 'QTUNIDESTSE',
      'LOCAL'       => 'QTUNIDESTLO',
      'REGIAO'      => '',
      'PADRAOQUALI' => '',
      'PADRAO'      => 'QTUNIDESTPR',
      'TIPOCARD'    => 'QTUNIDESTPRTP'
    ),
    'VRPEFATNUT' => array(
      'SERVICO'     => 'VRPEFATNUTSE',
      'LOCAL'       => 'VRPEFATNUTLO',
      'REGIAO'      => '',
      'PADRAOQUALI' => '',
      'PADRAO'      => 'VRPEFATNUTPR',
      'TIPOCARD'    => 'VRPEFATNUTPRTP'
    ),
    'QTCALCNUTR' => array(
      'SERVICO' => 'QTCALCNUTRSE',
      'LOCAL' => 'QTCALCNUTRLO',
      'REGIAO' => '',
      'PADRAOQUALI' => '',
      'PADRAO' => 'QTCALCNUTRPR',
      'TIPOCARD' => 'QTCALCNUTRPRTP'
    ),
    'QTBRUTAUNR' => array(
      'SERVICO' => 'QTBRUTASEUNR',
      'LOCAL' => 'QTBRUTALOUNR',
      'REGIAO' => 'QTBRUTAREGIAOUNR',
      'PADRAOQUALI' => 'QTBRUTAPADQUNR',
      'PADRAO' => 'QTBRUTAPRUNR',
      'TIPOCARD' => 'QTBRUTAPRUNRTP'
    ),
    'HRTEMPPREP' => array(
      'SERVICO' => 'HRTEMPPREPSE',
      'LOCAL' => 'HRTEMPPREPLO',
      'REGIAO' => '',
      'PADRAOQUALI' => '',
      'PADRAO' => 'HRTEMPPREPPR',
      'TIPOCARD' => 'HRTEMPPREPPRTP'
    ),
    'IDPRODBASE' => array(
      'SERVICO' => 'IDPRODBASESE',
      'LOCAL' => 'IDPRODBASELO',
      'REGIAO' => 'IDPRODBASEREGIAO',
      'PADRAOQUALI' => 'IDPRODBASEPR',
      'PADRAO' => 'IDPRODBASEPR',
      'TIPOCARD' => 'IDPRODBASEPRTP'
    ),
    'IDQTDEFIX' => array(
      'SERVICO' => 'IDQTDEFIXSE',
      'LOCAL' => 'IDQTDEFIXLO',
      'REGIAO' => 'IDQTDEFIXREGIAO',
      'PADRAOQUALI' => 'IDQTDEFIXPADQ',
      'PADRAO' => 'IDQTDEFIXPR',
      'TIPOCARD' => 'IDQTDEFIXPRTP'
    ),
    'QTCOMPLPROD' => array(
      'SERVICO' => 'QTCOMPLPRODSERV',
      'LOCAL' => 'QTCOMPLPRODFILI',
      'REGIAO' => '',
      'PADRAOQUALI' => '',
      'PADRAO' => 'QTCOMPLPRODPADR',
      'TIPOCARD' => ''
    ),
    'IDTPREQPROD' => array(
      'SERVICO' => 'IDTPREQPRODSERV',
      'LOCAL' => 'IDTPREQPRODFILI',
      'REGIAO' => '',
      'PADRAOQUALI' => '',
      'PADRAO' => 'IDTPREQPRODPADR',
      'TIPOCARD' => ''
    ),
    'QTLIMSEG' => array(
      'SERVICO' => 'QTLIMSEGSERV',
      'LOCAL' => 'QTLIMSEGFILI',
      'REGIAO' => '',
      'PADRAOQUALI' => '',
      'PADRAO' => 'QTLIMSEGPADR',
      'TIPOCARD' => ''
    ),
    'CODIGO' => array(
      'SERVICO'     => '',
      'LOCAL'       => '',
      'REGIAO'      => 'NRRECEREGIAO',
      'PADRAOQUALI' => 'NRRECEPADQUALI',
      'PADRAO'      => '',
      'TIPOCARD'    => ''
    )
);

  public function visibilityFieldsReceita(DTO\Request $request, DTO\Response $response) {
    try {
        $row = (Array) $request->getRow();
        $sql = "SELECT P.CDFILIAL, P.IDQTLIQUBRUT, P.IDAPRERECE, P.IDGANHOCOCC, P.IDAPROVCOCC, P.IDPERDALIMP, P.IDAPROVLIMP,
                       P.IDTEMPPREP, P.IDBLOALTRELO, P.IDUTREQCOMPENTD, G.IDBLOPRATLOC, G.CDNVBLPRAT, P.IDUTDIASLIMSEG, P.IDPERDADEGELO
                    FROM
                       PARAMGERAL G, PARAMPLANEJA P
                    WHERE
                       P.CDFILIAL = :P_CDFILIAL AND
                       P.CDPARPLANEJA = '1' AND
                       G.CDPARGERAL = '0001'";
                    
            $params = array(
                "P_CDFILIAL" => $row['CDFILIAL']
            );
            $std = $this->entityManager->getConnection()->prepare($sql);
            $std->execute($params);
            
            $result = $std->fetchAll();

        $response->addDataset(new DataSet('result', $result[0]));
    } catch (\Exception $e) {
          throw new \Exception($e->getMessage(), $e->getCode());
      }
  }

  public function saveRecipeStandard(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();

      $rows = $this->validRows($rows, 'recepadr');

      foreach ($rows as $row) {
        $this->insertRecipeStandard($row);        
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function insertRecipeStandard($row) {
    
    $params = array(
      'CDFILAUXPRAT'  => $row['CDFILAUXPRAT'],
      'CDPRATO'       => $row['CDPRATO'],
      'CDPRODUTO'     => $row['CDPRODUTO'],
      'VRPEFATCORPR'  => $row['VRPEFATCORPR'],
      'SGUNIDADE'     => $row['SGUNIDADE'],
      'VRPEFATCOCPR'  => $row['VRPEFATCOCPR'],
      'QTPRODPRAT'    => $row['QTPRODPRAT'],
      'HRTEMPPREPPR'  => str_replace(":", "", $row['HRTEMPPREPPR']),
      'QTUNIDESTPR'   => $row['QTUNIDESTPR'],
      'QTBRUTAPR'     => $row['QTBRUTAPR'],
      'IDPRODBASEPR'  => $row['IDPRODBASEPR'],
      'CDAPRERECE'    => $row['CDAPRERECE'],
      'VRPEFATNUTPR'  => $row['VRPEFATNUTPR'],
      'QTCALCNUTRPR'  => $row['QTCALCNUTRPR'],
      'QTBRUTAPRUNR'  => $row['QTBRUTAPRUNR'],
      'IDQTDEFIXPR'  => $row['IDQTDEFIXPR'],
      'QTLIMSEGPADR'  => $row['QTLIMSEGPADR'],
      'IDUTCOMPENTDIRP'  => $row['IDUTCOMPENTDIRP'],
      'QTCOMPLPRODPADR'  => $row['QTCOMPLPRODPADR'],
      'IDTPREQPRODPADR'  => $row['IDTPREQPRODPADR'],
      'VRPERCDEGELO' => $row['VRPERCDEGELO'],
      'CDOPERADOR' => $this->environment->getCdOperador()
    );
    
    if($row['__is_new']) {
      $params['NRORG'] = $this->utilities->getNrOrg();
      $query = "INSERT INTO RECEPADR (CDFILAUXPRAT, CDPRATO, CDPRODUTO, VRPEFATCORPR, SGUNIDADE, VRPEFATCOCPR, 
            QTPRODPRAT, HRTEMPPREPPR, QTUNIDESTPR, QTBRUTAPR, IDPRODBASEPR, CDAPRERECE, VRPEFATNUTPR, QTCALCNUTRPR, 
            QTBRUTAPRUNR, IDQTDEFIXPR, QTLIMSEGPADR, IDUTCOMPENTDIRP, QTCOMPLPRODPADR, IDTPREQPRODPADR, VRPERCDEGELO, NRORGINCLUSAO, NRORGULTATU,
            CDOPERINCLUSAO, CDOPERULTATU)
            VALUES (:CDFILAUXPRAT, :CDPRATO, :CDPRODUTO, :VRPEFATCORPR, :SGUNIDADE, :VRPEFATCOCPR, :QTPRODPRAT, :HRTEMPPREPPR, :QTUNIDESTPR, 
              :QTBRUTAPR, :IDPRODBASEPR, :CDAPRERECE, :VRPEFATNUTPR, :QTCALCNUTRPR, :QTBRUTAPRUNR, :IDQTDEFIXPR, :QTLIMSEGPADR, :IDUTCOMPENTDIRP, 
              :QTCOMPLPRODPADR, :IDTPREQPRODPADR, :VRPERCDEGELO, :NRORG, :NRORG, :CDOPERADOR, :CDOPERADOR)";
    } else {
      $query = "UPDATE RECEPADR SET VRPEFATCORPR = :VRPEFATCORPR, SGUNIDADE = :SGUNIDADE, VRPEFATCOCPR = :VRPEFATCOCPR, QTPRODPRAT = :QTPRODPRAT, HRTEMPPREPPR = :HRTEMPPREPPR, QTUNIDESTPR = :QTUNIDESTPR, IDUTCOMPENTDIRP = :IDUTCOMPENTDIRP,
                QTBRUTAPR = :QTBRUTAPR, IDPRODBASEPR = :IDPRODBASEPR, CDAPRERECE = :CDAPRERECE, VRPEFATNUTPR = :VRPEFATNUTPR, QTCALCNUTRPR = :QTCALCNUTRPR, QTBRUTAPRUNR = :QTBRUTAPRUNR, IDQTDEFIXPR = :IDQTDEFIXPR, QTLIMSEGPADR = :QTLIMSEGPADR,
                QTCOMPLPRODPADR = :QTCOMPLPRODPADR, IDTPREQPRODPADR = :IDTPREQPRODPADR, VRPERCDEGELO = :VRPERCDEGELO, CDOPERULTATU = :CDOPERADOR
                WHERE CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
    }  
    $this->connection->prepare($query)->execute($params);
  }
  
  public function saveRecipeTpCard(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();
      $rows = $this->validRows($rows, 'recetpcard');
      
      foreach ($rows as $row) {
        $this->insertRecipeTpCard($row);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function insertRecipeTpCard($row) {
    
    $params = array(
      'CDFILCENTPME'    => $row['CDFILCENTPME'],
      'CDTIPOCARD'      => $row['CDTIPOCARD'],
      'CDFILAUXPRAT'    => $row['CDFILAUXPRAT'],
      'CDPRATO'         => $row['CDPRATO'],
      'CDPRODUTO'       => $row['CDPRODUTO'],
      'VRPEFATCORPRTP'  => $row['VRPEFATCORPRTP'],
      'SGUNIDADE'       => $row['SGUNIDADE'],
      'VRPEFATCOCPRTP'  => $row['VRPEFATCOCPRTP'],
      'QTPRODPRATTP'    => $row['QTPRODPRATTP'],
      'HRTEMPPREPPRTP'  => str_replace(":", "", $row['HRTEMPPREPPRTP']),
      'QTUNIDESTPRTP'   => $row['QTUNIDESTPRTP'],
      'QTBRUTAPRTP'     => $row['QTBRUTAPRTP'],
      'IDPRODBASEPRTP'  => $row['IDPRODBASEPRTP'],
      'CDAPRERECE'      => $row['CDAPRERECE'],
      'VRPEFATNUTPRTP'  => $row['VRPEFATNUTPRTP'],
      'QTCALCNUTRPRTP'  => $row['QTCALCNUTRPRTP'],
      'QTBRUTAPRUNRTP'  => $row['QTBRUTAPRUNRTP'],
      'IDQTDEFIXPRTP'   => $row['IDQTDEFIXPRTP'],
      'VRPERCDEGELO'    => $row['VRPERCDEGELO'],
      'IDTPREQPRODPRTP' => $row['IDTPREQPRODPRTP'],
      'CDOPERADOR' => $this->environment->getCdOperador()
    );
    
    if($row['__is_new']) {
      $params['NRORG'] = $this->utilities->getNrOrg();
      $query = "INSERT INTO RECETPCARD (CDFILAUXPRAT, CDPRATO, CDFILCENTPME, CDTIPOCARD, CDPRODUTO, VRPEFATCOCPRTP,
                    QTPRODPRATTP, VRPEFATCORPRTP, SGUNIDADE, HRTEMPPREPPRTP, QTUNIDESTPRTP, QTBRUTAPRTP, IDTPREQPRODPRTP,
                    IDPRODBASEPRTP, CDAPRERECE,VRPEFATNUTPRTP,QTCALCNUTRPRTP, QTBRUTAPRUNRTP, IDQTDEFIXPRTP, VRPERCDEGELO, NRORGINCLUSAO, NRORGULTATU,
                    CDOPERINCLUSAO, CDOPERULTATU)
                VALUES (:CDFILAUXPRAT, :CDPRATO, :CDFILCENTPME, :CDTIPOCARD, :CDPRODUTO, :VRPEFATCOCPRTP,
                    :QTPRODPRATTP, :VRPEFATCORPRTP, :SGUNIDADE, :HRTEMPPREPPRTP, :QTUNIDESTPRTP, :QTBRUTAPRTP,
                    :IDPRODBASEPRTP, :CDAPRERECE,:VRPEFATNUTPRTP,:QTCALCNUTRPRTP, :QTBRUTAPRUNRTP, :IDQTDEFIXPRTP, :VRPERCDEGELO, :NRORG, :NRORG,
                    :CDOPERADOR, :CDOPERADOR)";
    } else {
      $query = "UPDATE RECETPCARD SET VRPEFATCORPRTP = :VRPEFATCORPRTP, SGUNIDADE = :SGUNIDADE, VRPEFATCOCPRTP = :VRPEFATCOCPRTP, QTPRODPRATTP = :QTPRODPRATTP, HRTEMPPREPPRTP = :HRTEMPPREPPRTP, QTUNIDESTPRTP = :QTUNIDESTPRTP, 
                QTBRUTAPRTP = :QTBRUTAPRTP, IDPRODBASEPRTP = :IDPRODBASEPRTP, CDAPRERECE = :CDAPRERECE, VRPEFATNUTPRTP = :VRPEFATNUTPRTP, QTCALCNUTRPRTP = :QTCALCNUTRPRTP, QTBRUTAPRUNRTP = :QTBRUTAPRUNRTP, IDTPREQPRODPRTP = :IDTPREQPRODPRTP, IDQTDEFIXPRTP = :IDQTDEFIXPRTP, VRPERCDEGELO = :VRPERCDEGELO, CDOPERULTATU = :CDOPERADOR
                WHERE CDFILCENTPME = :CDFILCENTPME AND CDTIPOCARD = :CDTIPOCARD AND CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
    }  
    $this->connection->prepare($query)->execute($params);
  }

  public function saveRecipeLocal(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();
      $rows = $this->validRows($rows, 'receitaLocal');

      foreach ($rows as $row) {
        $this->insertRecipeLocal($row);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function insertRecipeLocal($row) {
    
    if (isset($row['QTLIMSEGFILI']) == false) $row['QTLIMSEGFILI'] = null;
    if (isset($row['IDUTCOMPENTDIRF']) == false) $row['IDUTCOMPENTDIRF'] = 'N';
    if (isset($row['QTCOMPLPRODFILI']) == false) $row['QTCOMPLPRODFILI'] = 0;
    if (isset($row['IDTPREQPRODFILI']) == false) $row['IDTPREQPRODFILI'] = 'P';

    $params = array(
      'CDFILIAL'         => $row['CDFILIAL'],
      'CDFILAUXPRAT'     => $row['CDFILAUXPRAT'],
      'CDPRATO'          => $row['CDPRATO'],
      'CDPRODUTO'        => $row['CDPRODUTO'],
      'VRPEFATCORLO'     => $row['VRPEFATCORLO'],
      'SGUNIDADE'        => $row['SGUNIDADE'],
      'VRPEFATCOCLO'     => $row['VRPEFATCOCLO'],
      'QTPRODRECLOC'     => $row['QTPRODRECLOC'],
      'HRTEMPPREPLO'     => str_replace(":", "", $row['HRTEMPPREPLO']),
      'QTUNIDESTLO'      => $row['QTUNIDESTLO'],
      'QTBRUTALO'        => $row['QTBRUTALO'],
      'IDPRODBASELO'     => $row['IDPRODBASELO'],
      'CDAPRERECE'       => $row['CDAPRERECE'],
      'VRPEFATNUTLO'     => $row['VRPEFATNUTLO'],
      'QTCALCNUTRLO'     => $row['QTCALCNUTRLO'],
      'QTBRUTALOUNR'     => $row['QTBRUTALOUNR'],
      'IDQTDEFIXLO'      => $row['IDQTDEFIXLO'],
      'QTLIMSEGFILI'     => $row['QTLIMSEGFILI'],
      'IDUTCOMPENTDIRF'  => $row['IDUTCOMPENTDIRF'],
      'QTCOMPLPRODFILI'  => $row['QTCOMPLPRODFILI'],
      'IDTPREQPRODFILI'  => $row['IDTPREQPRODFILI'],
      'VRPERCDEGELO'     => $row['VRPERCDEGELO'],
      'CDOPERADOR' => $this->environment->getCdOperador()
    );
    
    if($row['__is_new']) {
      $params['NRORG'] = $this->utilities->getNrOrg();
      $query = "INSERT INTO RECEFILI (CDFILAUXPRAT, CDPRATO, CDFILIAL, CDPRODUTO, SGUNIDADE, VRPEFATCOCLO, 
                  QTPRODRECLOC, VRPEFATCORLO, HRTEMPPREPLO, QTUNIDESTLO, QTBRUTALO, IDPRODBASELO, 
                  CDAPRERECE, VRPEFATNUTLO, QTCALCNUTRLO, QTBRUTALOUNR, IDQTDEFIXLO, QTLIMSEGFILI, IDUTCOMPENTDIRF, QTCOMPLPRODFILI, IDTPREQPRODFILI, 
                  VRPERCDEGELO, NRORGINCLUSAO, NRORGULTATU, CDOPERINCLUSAO, CDOPERULTATU)
              VALUES (:CDFILAUXPRAT, :CDPRATO, :CDFILIAL, :CDPRODUTO, :SGUNIDADE, :VRPEFATCOCLO, 
                  :QTPRODRECLOC, :VRPEFATCORLO, :HRTEMPPREPLO, :QTUNIDESTLO, :QTBRUTALO, 
                  :IDPRODBASELO, :CDAPRERECE, :VRPEFATNUTLO, :QTCALCNUTRLO, :QTBRUTALOUNR, :IDQTDEFIXLO, :QTLIMSEGFILI, :IDUTCOMPENTDIRF, :QTCOMPLPRODFILI, 
                  :IDTPREQPRODFILI, :VRPERCDEGELO, :NRORG, :NRORG, :CDOPERADOR, :CDOPERADOR)";
    } else {
      $query = "UPDATE RECEFILI SET VRPEFATCORLO = :VRPEFATCORLO, SGUNIDADE = :SGUNIDADE, VRPEFATCOCLO = :VRPEFATCOCLO, QTPRODRECLOC = :QTPRODRECLOC, HRTEMPPREPLO = :HRTEMPPREPLO, QTUNIDESTLO = :QTUNIDESTLO, 
                QTBRUTALO = :QTBRUTALO, IDPRODBASELO = :IDPRODBASELO, CDAPRERECE = :CDAPRERECE, VRPEFATNUTLO = :VRPEFATNUTLO, QTCALCNUTRLO = :QTCALCNUTRLO, QTBRUTALOUNR = :QTBRUTALOUNR, IDQTDEFIXLO = :IDQTDEFIXLO,
                QTLIMSEGFILI = :QTLIMSEGFILI, IDUTCOMPENTDIRF = :IDUTCOMPENTDIRF, QTCOMPLPRODFILI = :QTCOMPLPRODFILI, IDTPREQPRODFILI = :IDTPREQPRODFILI, VRPERCDEGELO = :VRPERCDEGELO, CDOPERULTATU = :CDOPERADOR
                WHERE CDFILIAL = :CDFILIAL AND CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
    }  
    $this->connection->prepare($query)->execute($params);
  }
  
  public function saveRecipeRegion(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();

      $rows = (Array) $request->getRow();
      $rows = $this->validRows($rows, 'receregiao');

      foreach ($rows as $row) {
        $this->insertRecipeRegion($row);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }
  
  public function insertRecipeRegion($row) {
    
    if ($row['NRRECEREGIAO'] == 0 || $row['NRRECEREGIAO'] == '') $nrreceregiao = $this->newCode->getCodeByTableName('RECEREGIAO', $this->utilities->getNrOrg());
    else $nrreceregiao = $row['NRRECEREGIAO'];
    if ($row['IDPRODBASEREGIAO'] === 'P' || $row['IDPRODBASEREGIAO'] === null) $row['IDPRODBASEREGIAO'] = 'N';
    if ($row['IDQTDEFIXREGIAO'] === null) $row['IDQTDEFIXREGIAO'] = 'N';

    $params = array(
      "NRRECEREGIAO"      => $nrreceregiao,
      "CDFILAUXPRAT"      => $row['CDFILAUXPRAT'],
      "CDPRATO"           => $row['CDPRATO'],
      "CDREGIAO"          => $row['CDREGIAO'],
      "NRPADRAOQUALIDADE" => $row['NRPADRAOQUALIDADE'],
      "CDPRODUTO"         => $row['CDPRODUTO'],
      "QTPRODRECREGIAO"   => $row['QTPRODRECREGIAO'],
      "VRPEFATCOCREGIAO"  => $row['VRPEFATCOCREGIAO'],
      "VRPEFATCORREGIAO"  => $row['VRPEFATCORREGIAO'],
      "SGUNIDADE"         => $row['SGUNIDADE'],
      "QTBRUTAREGIAOUNR"  => $row['QTBRUTAREGIAOUNR'],
      "IDPRODBASEREGIAO"  => $row['IDPRODBASEREGIAO'],
      "IDQTDEFIXREGIAO"   => $row['IDQTDEFIXREGIAO'],
      'CDOPERADOR' => $this->environment->getCdOperador()
    );
    
    if($row['__is_new']) {
      $params['NRORG'] = $this->utilities->getNrOrg();
      $query = "INSERT INTO RECEREGIAO ( NRRECEREGIAO, CDFILAUXPRAT, CDPRATO, CDREGIAO, NRPADRAOQUALIDADE, CDPRODUTO, QTPRODRECREGIAO, VRPEFATCOCREGIAO, 
                  VRPEFATCORREGIAO, SGUNIDADE, QTBRUTAREGIAOUNR, IDPRODBASEREGIAO, IDQTDEFIXREGIAO, NRORG, NRORGINCLUSAO, NRORGULTATU, DTINCLUSAO, DTULTATU, 
                  CDOPERINCLUSAO, CDOPERULTATU) VALUES  ( :NRRECEREGIAO, :CDFILAUXPRAT, :CDPRATO, :CDREGIAO, :NRPADRAOQUALIDADE, :CDPRODUTO, :QTPRODRECREGIAO,
                  :VRPEFATCOCREGIAO, :VRPEFATCORREGIAO, :SGUNIDADE, :QTBRUTAREGIAOUNR, :IDPRODBASEREGIAO, :IDQTDEFIXREGIAO, :NRORG, :NRORG, :NRORG, SYSDATE, SYSDATE,
                  :CDOPERADOR, :CDOPERADOR)";
    } else {
      $query = "UPDATE RECEREGIAO SET CDREGIAO = :CDREGIAO, NRPADRAOQUALIDADE = :NRPADRAOQUALIDADE, QTPRODRECREGIAO = :QTPRODRECREGIAO, 
                  VRPEFATCOCREGIAO = :VRPEFATCOCREGIAO, VRPEFATCORREGIAO = :VRPEFATCORREGIAO, SGUNIDADE = :SGUNIDADE, QTBRUTAREGIAOUNR = :QTBRUTAREGIAOUNR, 
                  IDPRODBASEREGIAO = :IDPRODBASEREGIAO, IDQTDEFIXREGIAO = :IDQTDEFIXREGIAO, CDOPERULTATU = :CDOPERADOR WHERE NRRECEREGIAO = :NRRECEREGIAO 
                  AND CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
    }
    
    $this->connection->prepare($query)->execute($params);
  }
  
  public function saveRecipePadraoQualidade(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();
      $rows = (Array) $request->getRow();
      $rows = $this->validRows($rows, 'recepadquali');
  
      foreach ($rows as $row) {
        $this->insertRecipeQual($row);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function insertRecipeQual($row) {
    
    if ($row['NRRECEPADQUALI'] == 0 || $row['NRRECEPADQUALI'] == '') $nrrecepadquali = $this->newCode->getCodeByTableName('RECEPADQUALI', $this->utilities->getNrOrg());
    else $nrrecepadquali = $row['NRRECEPADQUALI'];
    if ($row['IDPRODBASEPADQ'] == null) $row['IDPRODBASEPADQ'] = 'N';
    if ($row['IDQTDEFIXPADQ'] == null) $row['IDQTDEFIXPADQ'] = 'N';
    
    $params = array(
      "NRRECEPADQUALI"    => $nrrecepadquali,
      "CDFILAUXPRAT"      => $row['CDFILAUXPRAT'],
      "CDPRATO"           => $row['CDPRATO'],
      "NRPADRAOQUALIDADE" => $row['NRPADRAOQUALIDADE'],
      "CDPRODUTO"         => $row['CDPRODUTO'],
      "QTPRODRECPADQ"     => $row['QTPRODRECPADQ'],
      "VRPEFATCOCPADQ"    => $row['VRPEFATCOCPADQ'],
      "VRPEFATCORPADQ"    => $row['VRPEFATCORPADQ'],
      "SGUNIDADE"         => $row['SGUNIDADE'],
      "QTBRUTAPADQUNR"    => $row['QTBRUTAPADQUNR'],
      "IDPRODBASEPADQ"    => $row['IDPRODBASEPADQ'],
      "IDQTDEFIXPADQ"     => $row['IDQTDEFIXPADQ'],
      'CDOPERADOR' => $this->environment->getCdOperador()
    );
    
    if($row['__is_new']) {
      $params['NRORG'] = $this->utilities->getNrOrg();
      $query = "INSERT INTO RECEPADQUALI ( NRRECEPADQUALI, CDFILAUXPRAT, CDPRATO, NRPADRAOQUALIDADE, CDPRODUTO, QTPRODRECPADQ, VRPEFATCOCPADQ, VRPEFATCORPADQ,
                SGUNIDADE, QTBRUTAPADQUNR, IDPRODBASEPADQ, IDQTDEFIXPADQ, NRORG, NRORGULTATU, NRORGINCLUSAO, DTINCLUSAO, DTULTATU, CDOPERINCLUSAO, CDOPERULTATU) 
                VALUES ( :NRRECEPADQUALI, :CDFILAUXPRAT, :CDPRATO,:NRPADRAOQUALIDADE, :CDPRODUTO, :QTPRODRECPADQ, :VRPEFATCOCPADQ, :VRPEFATCORPADQ, :SGUNIDADE, 
                :QTBRUTAPADQUNR, :IDPRODBASEPADQ, :IDQTDEFIXPADQ, :NRORG, :NRORG, :NRORG, SYSDATE, SYSDATE, :CDOPERADOR, :CDOPERADOR)";
    } else {
      $query = "UPDATE RECEPADQUALI SET QTPRODRECPADQ = :QTPRODRECPADQ, VRPEFATCOCPADQ = :VRPEFATCOCPADQ, VRPEFATCORPADQ = :VRPEFATCORPADQ, SGUNIDADE = :SGUNIDADE, 
      QTBRUTAPADQUNR = :QTBRUTAPADQUNR, IDPRODBASEPADQ = :IDPRODBASEPADQ, IDQTDEFIXPADQ = :IDQTDEFIXPADQ, CDOPERULTATU = :CDOPERADOR WHERE NRRECEPADQUALI = :NRRECEPADQUALI 
      AND NRPADRAOQUALIDADE = :NRPADRAOQUALIDADE AND CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
    }
    
    $this->connection->prepare($query)->execute($params);
  }

  public function saveRecipeService(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();
      $rows = (Array) $request->getRow();
      $rows = $this->validRows($rows, 'receitaServico');
      
      foreach ($rows as $row) {
        $this->insertRecipeService($row);
      }
    
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }

  public function insertRecipeService($row) {
    
    $params = array(
      'CDFILIAL'  => $row['CDFILIAL'],
      'CDSERVFILI'  => $row['CDSERVFILI'],
      'CDFILAUXPRAT'  => $row['CDFILAUXPRAT'],
      'CDPRATO'       => $row['CDPRATO'],
      'CDPRODUTO'     => $row['CDPRODUTO'],
      'VRPEFATCORSE'  => $row['VRPEFATCORSE'],
      'SGUNIDADE'     => $row['SGUNIDADE'],
      'VRPEFATCOCSE'  => $row['VRPEFATCOCSE'],
      'QTPRODRECSER'    => $row['QTPRODRECSER'],
      'HRTEMPPREPSE'  => str_replace(":", "", $row['HRTEMPPREPSE']),
      'QTUNIDESTSE'   => $row['QTUNIDESTSE'],
      'QTBRUTASEUNR'     => $row['QTBRUTASEUNR'],
      'IDPRODBASESE'  => $row['IDPRODBASESE'],
      'CDAPRERECE'    => $row['CDAPRERECE'],
      'VRPEFATNUTSE'  => $row['VRPEFATNUTSE'],
      'QTCALCNUTRSE'  => $row['QTCALCNUTRSE'],
      'QTBRUTASE'  => $row['QTBRUTASE'],
      'IDQTDEFIXSE'  => $row['IDQTDEFIXSE'],
      'QTLIMSEGSERV'  => $row['QTLIMSEGSERV'],
      'IDUTCOMPENTDIRS'  => $row['IDUTCOMPENTDIRS'],
      'QTCOMPLPRODSERV'  => $row['QTCOMPLPRODSERV'],
      'IDTPREQPRODSERV'  => $row['IDTPREQPRODSERV'],
      'VRPERCDEGELO'     => $row['VRPERCDEGELO'],
      'CDOPERADOR' => $this->environment->getCdOperador()
    );
    
    if($row['__is_new']) {
      $params['NRORG'] = $this->utilities->getNrOrg();
      $query = "INSERT INTO RECESERV (CDFILAUXPRAT, CDPRATO, CDFILIAL, CDSERVFILI, CDPRODUTO, VRPEFATCOCSE, QTPRODRECSER, VRPEFATCORSE, SGUNIDADE, HRTEMPPREPSE,
                QTUNIDESTSE, QTBRUTASE, IDPRODBASESE, CDAPRERECE,VRPEFATNUTSE,QTCALCNUTRSE, QTBRUTASEUNR, IDQTDEFIXSE, QTLIMSEGSERV, IDUTCOMPENTDIRS, QTCOMPLPRODSERV,
                IDTPREQPRODSERV, VRPERCDEGELO, NRORGINCLUSAO, NRORGULTATU, CDOPERINCLUSAO, CDOPERULTATU, DTINCLUSAO, DTULTATU)
              VALUES (:CDFILAUXPRAT, :CDPRATO, :CDFILIAL, :CDSERVFILI, :CDPRODUTO, :VRPEFATCOCSE, :QTPRODRECSER, :VRPEFATCORSE, :SGUNIDADE, :HRTEMPPREPSE, :QTUNIDESTSE, 
                  :QTBRUTASE, :IDPRODBASESE, :CDAPRERECE, :VRPEFATNUTSE, :QTCALCNUTRSE, :QTBRUTASEUNR, :IDQTDEFIXSE, :QTLIMSEGSERV, :IDUTCOMPENTDIRS, :QTCOMPLPRODSERV,
                  :IDTPREQPRODSERV, :VRPERCDEGELO, :NRORG, :NRORG, :CDOPERADOR, :CDOPERADOR, SYSDATE, SYSDATE)
              ";
    } else {
      $query = "UPDATE RECESERV SET VRPEFATCORSE = :VRPEFATCORSE, SGUNIDADE = :SGUNIDADE, VRPEFATCOCSE = :VRPEFATCOCSE, QTPRODRECSER = :QTPRODRECSER, HRTEMPPREPSE = :HRTEMPPREPSE, QTUNIDESTSE = :QTUNIDESTSE, 
                QTBRUTASE = :QTBRUTASE, IDPRODBASESE = :IDPRODBASESE, CDAPRERECE = :CDAPRERECE, VRPEFATNUTSE = :VRPEFATNUTSE, QTCALCNUTRSE = :QTCALCNUTRSE, QTBRUTASEUNR = :QTBRUTASEUNR, IDQTDEFIXSE = :IDQTDEFIXSE,
                QTLIMSEGSERV = :QTLIMSEGSERV, IDUTCOMPENTDIRS = :IDUTCOMPENTDIRS, QTCOMPLPRODSERV = :QTCOMPLPRODSERV, IDTPREQPRODSERV = :IDTPREQPRODSERV, VRPERCDEGELO = :VRPERCDEGELO, CDOPERULTATU = :CDOPERADOR
                WHERE CDFILIAL = :CDFILIAL AND CDSERVFILI = :CDSERVFILI AND  CDPRATO = :CDPRATO AND CDFILAUXPRAT = :CDFILAUXPRAT AND CDPRODUTO = :CDPRODUTO";
    }  

    $this->connection->prepare($query)->execute($params);
  }

  private function validRows($rows, $dataSourceName) {
    $dataSet = new DataSet($dataSourceName, $rows);
    $request = new DTO\Request\DataSet($dataSet, "", "", "");
    $rowsToSave = $this->crudService->getRowsToSave($request, $dataSourceName);
    return $rowsToSave;
  }

  public function saveImportRecipe(DTO\Request $request, DTO\Response $response) {
    try {
      $this->connection->beginTransaction();
      
      $params = (Array) $request->getRow();
      $rows = $params[0];
      $prodDest = $params[1];

      $firstRow = $rows[0];
      $dest = $firstRow['RECIPEDEST'];
      
      //Dados Origem
      $cdfilcentpmeO           = $firstRow['ORIGEM']['CDFILCENTPME'];
      $pratoOrigem             = $firstRow['CDPRATO'];
      $cdFilAuxPratoOrigem     = $firstRow['CDFILAUXPRAT'];
      $receitaOrigem           = $firstRow['TIPO'];
      $cdregiaoOrigem          = $receitaOrigem == 'REGIAO' ? $firstRow['ORIGEM']['CDREGIAO'] : null;
      $nrpadraoqualidadeOrigem = $receitaOrigem == "PADRAOQUALI" || $receitaOrigem == 'REGIAO'  ? $firstRow['ORIGEM']['CDPADRAOQUALIDADE'] : null;
      $filialO                 = $receitaOrigem == "LOCAL" || $receitaOrigem == "SERVICO" ? $firstRow['ORIGEM']['CDFILIAL'] : null;
      $servicoO                = $receitaOrigem == "SERVICO" ? $firstRow['ORIGEM']['CDSERVFILI'] : null;
      $tipocardO               = $receitaOrigem == "TIPOCARD" ? $firstRow['ORIGEM']['CDTIPOCARD'] : null;
      
      //Dados Destino
      if (empty($prodDest) != true && count($prodDest) > 1) {
        foreach ($prodDest as $prod) {
          $cdfilcentpmeD            = $prod['CDFILCENTPME'];
          $pratoDestino             = $prod['CDPRATO'];
          $cdFilAuxPratoDestino     = $prod['CDFILAUXPRAT'];
          $receitaDestino           = $dest;
          $cdregiaoDestino          = (isset($prod['CDREGIAO']) ) ? $prod['CDREGIAO'] : null;
          $nrpadraoqualidadeDestino = (isset($prod['NRPADRAOQUALIDADE']) )  ? $prod['NRPADRAOQUALIDADE'] : null;
          $filialD                  = $receitaDestino == "LOCAL" || $receitaDestino == "SERVICO" ? $prod['CDFILIAL'] : null;
          $servicoD                 = $receitaDestino == "SERVICO" ? $prod['CDSERVFILI'] : null;
          $tipocardD                = $receitaDestino == "TIPOCARD" ? $prod['CDTIPOCARD'] : null;
        }
      } else {
        $cdfilcentpmeD            = $prodDest[0]['CDFILCENTPME'];
        $pratoDestino             = isset($firstRow['CDPRATO_D']) ? $firstRow['CDPRATO_D'] : $firstRow['CDPRATO'];
        $cdFilAuxPratoDestino     = $firstRow['CDFILAUXPRAT'];
        $receitaDestino           = $firstRow['RECIPEDEST'];
        $cdregiaoDestino          = (isset($firstRow['CDREGIAO']) ) ? $firstRow['CDREGIAO'] : null;
        $nrpadraoqualidadeDestino = (isset($firstRow['NRPADRAOQUALIDADE']) )  ? $firstRow['NRPADRAOQUALIDADE'] : null;
        $filialD                  = $receitaDestino == "LOCAL" || $receitaDestino == "SERVICO" ? $firstRow['CDFILIAL'] : null;
        $servicoD                 = $receitaDestino == "SERVICO" ? $firstRow['CDSERVFILI'] : null;
        $tipocardD                = $receitaDestino == "TIPOCARD" ? $firstRow['CDTIPOCARD'] : null;
      }
      
      switch ($receitaDestino) {
        case 'REGIAO':
          $dataSourceDestino = 'receregiao';
          $dadosPratoDestino = 'pratregiao';
        break;
        case 'PADRAOQUALI':
          $dataSourceDestino = 'recepadquali';
          $dadosPratoDestino = 'pratpadquali';
        break;
        case 'PADRAO':
          $dataSourceDestino = 'recepadr';
          $dadosPratoDestino = 'pratpadr';
        break;
        case 'SERVICO':
          $dataSourceDestino = 'receserv';
          $dadosPratoDestino = 'pratserv';
        break;
        case 'LOCAL':
          $dataSourceDestino = 'recefili';
          $dadosPratoDestino = 'pratfili';
        break;
        case 'TIPOCARD':
          $dataSourceDestino = 'recetpcard';
          $dadosPratoDestino = 'prattpcard';
        break;
      }

      switch ($receitaOrigem) {
        case 'REGIAO':
          $dataSourceOrigem = 'receregiao';
          $dadosPratoOrigem = 'pratregiao';
        break;
        case 'PADRAOQUALI':
          $dataSourceOrigem = 'recepadquali';
          $dadosPratoOrigem = 'pratpadquali';
        break;
        case 'PADRAO':
          $dataSourceOrigem = 'recepadr';
          $dadosPratoOrigem = 'pratpadr';
        break;
        case 'SERVICO':
          $dataSourceOrigem = 'receserv';
          $dadosPratoOrigem = 'pratserv';
        break;
        case 'LOCAL':
          $dataSourceOrigem = 'recefili';
          $dadosPratoOrigem = 'pratfili';
        break;
        case 'TIPOCARD':
          $dataSourceOrigem = 'recetpcard';
          $dadosPratoOrigem = 'prattpcard';
        break;
      }
      
      $conditionsDestino = array( //filtro Destino
        array(
          "columnName" => "CDPRATO",
          "operator" => "=",
          "value" => $pratoDestino
        ),
        array(
          "columnName" => "CDFILAUXPRAT",
          "operator" => "=",
          "value" => $cdFilAuxPratoDestino
        ),
        array(
          "columnName" => "NRORG",
          "operator" => "=",
          "value" => $this->utilities->getNrOrg()
        )
      );
      
      if($receitaDestino == 'REGIAO' || $receitaDestino == 'PADRAOQUALI') {
        if($receitaDestino == 'REGIAO') {
          array_push($conditionsDestino, 
            array(
              "columnName" => "CDREGIAO",
              "operator" => "=",
              "value" => $cdregiaoDestino
            )
          );
        }
        array_push($conditionsDestino, 
          array(
            "columnName" => "NRPADRAOQUALIDADE",
            "operator" => "=",
            "value" => $nrpadraoqualidadeDestino
          )
        );
      } else if($receitaDestino == 'SERVICO' || $receitaDestino == 'LOCAL') {
        if($receitaDestino == 'SERVICO') {
          array_push(
            $conditionsDestino, 
            array(
              "columnName" => "CDSERVFILI",
              "operator" => "=",
              "value" => $servicoD
            )
          );
        }
        
        array_push($conditionsDestino, 
          array(
            "columnName" => "CDFILIAL",
            "operator" => "=",
            "value" => $filialD
          )
        );
      } else if ($receitaDestino == 'TIPOCARD') {
        array_push(
          $conditionsDestino, 
          array(
            "columnName" => "CDTIPOCARD",
            "operator" => "=",
            "value" => $tipocardD
          ),
          array(
            "columnName" => "CDFILCENTPME",
            "operator" => "=",
            "value" => $cdfilcentpmeD
          )
        );
      }
      
      
      $dataSetProdRecD = $this->crudService->getFilteredDataSet($dataSourceDestino, $conditionsDestino);
      $prodRec_D = $dataSetProdRecD->getRows();
      
      //BUSCA DADOS DA RECEITA DE DESTINO E EXCLUI
      $dataSet = $this->crudService->getFilteredDataSet($dadosPratoDestino, $conditionsDestino);
      $this->dataSourceManager->delete($dataSet);
      
      $conditionsOrigem = array(// Filtro Origem
        array(
          "columnName" => "CDPRATO",
          "operator" => "=",
          "value" => $pratoOrigem
        ),
        array(
          "columnName" => "CDFILAUXPRAT",
          "operator" => "=",
          "value" => $cdFilAuxPratoOrigem
        ),
        array(
          "columnName" => "NRORG",
          "operator" => "=",
          "value" => $this->utilities->getNrOrg()
        )
      );
      
      $dataSetProdRecO = $this->crudService->getFilteredDataSet($dataSourceOrigem, $conditionsOrigem);
      $prodRec_O = $dataSetProdRecO->getRows();

      if($receitaOrigem == 'REGIAO' || $receitaOrigem == 'PADRAOQUALI'){
        if($receitaOrigem == 'REGIAO') {
          array_push($conditionsOrigem,
            array(
              "columnName" => "CDREGIAO",
              "operator" => "=",
              "value" => $cdregiaoOrigem
            )
          );
        }
        array_push($conditionsOrigem,
          array(
            "columnName" => "NRPADRAOQUALIDADE",
            "operator" => "=",
            "value" => $nrpadraoqualidadeOrigem
          )
        );
      } else if($receitaOrigem == 'SERVICO' || $receitaOrigem == 'LOCAL') {
        if($receitaOrigem == 'SERVICO') {
          array_push($conditionsOrigem, 
            array(
              "columnName" => "CDSERVFILI",
              "operator" => "=",
              "value" => $servicoO
            )
          );
        }
        array_push($conditionsOrigem, 
          array(
            "columnName" => "CDFILIAL",
            "operator" => "=",
            "value" => $filialO
          )
        );
      } else if ($receitaOrigem == 'TIPOCARD') {
        array_push(
          $conditionsOrigem, 
          array(
            "columnName" => "CDTIPOCARD",
            "operator" => "=",
            "value" => $tipocardO
          ),
          array(
            "columnName" => "CDFILCENTPME",
            "operator" => "=",
            "value" => $cdfilcentpmeO
          )
        );
      }

      $pratpadrO = $this->crudService->getFilteredDataSet($dadosPratoOrigem, $conditionsOrigem)->getRows();

      if ($firstRow['IMPORTTYPE'] !== 'SOBREPOR') { // acrescentar
        if ($prodRec_D) {
          foreach ($prodRec_D as $prodD) {
            foreach ($rows as $indice => $prodO) {
              if ($prodO['CDPRODUTO'] === $prodD['CDPRODUTO']) {
                unset($rows[$indice]);
                continue 1;
              }
            }
          }
        }
      } else $this->dataSourceManager->delete($dataSetProdRecD); // soprepor
      
      foreach ($rows as $novosProdutos) {
        if($dest == 'REGIAO' || $dest == 'PADRAOQUALI') {
          $code = $this->newCode->getCodeByTableName(strtoupper($dataSourceDestino), $this->utilities->getNrOrg());
          $novosProdutos['CODIGO'] = $code;
        }
        $novosProdutos['CDPRATO']           = $pratoDestino;
        $novosProdutos['CDFILAUXPRAT']      = $cdFilAuxPratoDestino;
        $novosProdutos['CDREGIAO']          = $cdregiaoDestino;
        $novosProdutos['NRPADRAOQUALIDADE'] = $nrpadraoqualidadeDestino;
        $this->insereReceita($novosProdutos, $receitaOrigem, $receitaDestino, $dest);
      }
      
      $tpImportacao = $firstRow['IMPORTTYPE'];
      
      if ($pratpadrO) $this->insertDadosPrato($pratpadrO, $receitaOrigem, $tpImportacao, $dataSourceDestino, $cdFilAuxPratoDestino, $pratoDestino, $filialD, $servicoD, $cdregiaoDestino, $nrpadraoqualidadeDestino, $tipocardD, $cdfilcentpmeD);
      
      $this->connection->commit();
      $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
    } catch (\Exception $e) {
      $this->connection->rollback();
      $response->setError(new DTO\Response\Error($e->getMessage(), 1));
    }
  }
  
  public function insereReceita($row, $receitaOrigem, $receitaDestino, $dest) {
    $dadosReceitaInserir = array(
      '__is_new'                                         => true,
      // 'NRORG'                                            => $row['NRORG'],
      'NRORG'                                            => $this->utilities->getNrOrg(),
      'CDPRATO'                                          => $row['CDPRATO'],
      'CDFILIAL'                                         => $row['CDFILIAL'],
      'CDPRODUTO'                                        => $row['CDPRODUTO'],
      'SGUNIDADE'                                        => $row['SGUNIDADE'],
      'CDSERVFILI'                                       => $row['CDSERVFILI'],
      'CDTIPOCARD'                                       => $row['CDTIPOCARD'], 
      'CDFILAUXPRAT'                                     => $row['CDFILAUXPRAT'],
      'CDFILCENTPME'                                     => $row['CDFILCENTPME'],
      $this->keysMapping['QTBRUTA'][$receitaDestino]     => isset($row['QTBRUTA'])  ? $row['QTBRUTA']   : null,
      $this->keysMapping['QTBRUTAUNR'][$receitaDestino]  => isset($row['QTBRUTAUNR'])  ? $row['QTBRUTAUNR']   : '',
      $this->keysMapping['QTPROD'][$receitaDestino]      => isset($row['QTPRODPRAT'])   ? $row['QTPRODPRAT']    : null,
      $this->keysMapping['VRPEFATNUT'][$receitaDestino]  => isset($row['VRPEFATNUT'])   ? $row['VRPEFATNUT']    : "0",
      $this->keysMapping['VRPEFATCOR'][$receitaDestino]  => isset($row['VRPEFATCOR'])    ? $row['VRPEFATCOR']     : "0",
      $this->keysMapping['QTUNIDEST'][$receitaDestino]   => isset($row['QTUNIDEST'])    ? $row['QTUNIDEST']     : null,
      'CDAPRERECE'                                       => isset($row['CDAPRERECE'])     ? $row['CDAPRERECE']      : null,
      $this->keysMapping['VRPEFATCOC'][$receitaDestino]  => isset($row['VRPEFATCOC'])     ? $row['VRPEFATCOC']      : "0",
      $this->keysMapping['VRPEFATNUT'][$receitaDestino]  => isset($row['VRPEFATNUT'])   ? $row['VRPEFATNUT']    : "0",
      $this->keysMapping['QTLIMSEG'][$receitaDestino]    => isset($row['QTLIMSEG'])      ? $row['QTLIMSEG']       : null,
      $this->keysMapping['QTCALCNUTR'][$receitaDestino]  => isset($row['QTCALCNUTR'])   ? $row['QTCALCNUTR']    : null,
      // $this->keysMapping['QTBRUTAUNR'][$receitaDestino]  => isset($row['QTBRUTA'])      ? $row['QTBRUTA']       : null,
      $this->keysMapping['QTCOMPLPROD'][$receitaDestino] => isset($row['QTCOMPL'])      ? $row['QTCOMPL']       : null,
      $this->keysMapping['HRTEMPPREP'][$receitaDestino]  => isset($row['HRTEMPPREP'])       ? $row['HRTEMPPREP']        : null,
      $this->keysMapping['IDQTDEFIX'][$receitaDestino]   => isset($row['IDQTDEFIX'])       ? $row['IDQTDEFIX']        : "N",
      'IDUTCOMPENTDIR'.$receitaDestino                   => isset($row['ENTDIR'])       ? $row['ENTDIR']        : "N",
      $this->keysMapping['IDTPREQPROD'][$receitaDestino] => isset($row['TPREQ'])        ? $row['TPREQ']         : "P",
      $this->keysMapping['IDPRODBASE'][$receitaDestino]  => isset($row['IDPRODBASE'])         ? $row['IDPRODBASE']          : "N",
      $this->keysMapping['CODIGO'][$receitaDestino]      => isset($row['CODIGO'])       ? $row['CODIGO']        : null,
      'NRPADRAOQUALIDADE'                                => isset($row['NRPADRAOQUALIDADE']) ? $row['NRPADRAOQUALIDADE'] : null,
      'CDREGIAO'                                         => isset($row['CDREGIAO'])     ? $row['CDREGIAO']      : null,
      'VRPERCDEGELO'                                     => isset($row['VRPERCDEGELO']) ? $row['VRPERCDEGELO']  : "0"
    );

    switch ($receitaDestino) {
      case 'REGIAO':
        $tabela = 'receregiao';
      break;
      case 'PADRAOQUALI':
        $tabela = 'recepadquali';
      break;
      case 'PADRAO':
        $tabela = 'recepadr';
      break;
      case 'SERVICO':
        $tabela = 'receserv';
      break;
      case 'LOCAL':
        $tabela = 'recefili';
      break;
      case 'TIPOCARD':
        $tabela = 'recetpcard';
      break;
    }
    $requestInsertReceitaPrato = new DTO\Request\Row($dadosReceitaInserir, '', '', '');
    $dadosReceitaInserir = $this->crudService->getRowsToSave($requestInsertReceitaPrato, $tabela);
    $this->crudService->save($tabela, $dadosReceitaInserir);
  }
  
  public function insertDadosPrato ($pratpadrO, $receitaOrigem, $tpImportacao, $dataSourceDestino, $cdFilAuxPratoDestino, $pratoDestino, $filialD, $servicoD, $cdregiaoDestino, $nrpadraoqualidadeDestino, $tipocardD, $cdfilcentpmeD) {
    
    $cdfilcentpme  = $cdfilcentpmeD;
    $pratpadrO     = $pratpadrO[0];
    $corAux        = null;
    $corSeq        = null;
    $container     = null;
    $hora          = null;
    $nomeFant      = null;
    $qtCarb        = null;
    $qtLip         = null;
    $qtProt        = null;
    $qtCal         = null;
    $qtAlc         = null;
    $qtMin         = null;
    $qtAmost       = null;
    $prodProd      = isset($pratpadrO['CDPRODPRODUCAO']) ? $pratpadrO['CDPRODPRODUCAO'] : null;
    $qtLim         = null;
    $idProdChill   = isset($pratpadrO['IDPRODCHILL']) ? $pratpadrO['IDPRODCHILL'] : null;
    $idTpProdChill = isset($pratpadrO['IDTPPRODCHILL']) ? $pratpadrO['IDTPPRODCHILL'] : null;
    $idFinal       = null;
    $cdmediacase   = isset($pratpadrO['CDMEDICASE']) ? $pratpadrO['CDMEDICASE'] : null;
    $qtmedicas     = null;
    $idativo       = null;
    $dsprato       = null;
    $dtinativauto  = null;
    
    switch ($receitaOrigem) {
      case 'REGIAO':
        $cor        = $pratpadrO['NRCORPRIREGIAO'];
        $quantidade = $pratpadrO['QTPADRAOREGIAO'];
        $dtinativauto = $pratpadrO['DTINATIVAUTO'];
      break;
      case 'PADRAOQUALI':
        $cor        = $pratpadrO['NRCORPRIPADQ'];
        $quantidade = $pratpadrO['QTPADRAOPADQ'];
        $dtinativauto = $pratpadrO['DTINATIVAUTO'];
      break;
      case 'PADRAO':
        $cor        = $pratpadrO['NRCORPRIPRAT'];
        $quantidade = $pratpadrO['QTPADRAOPRAT'];
        $corSeq     = $pratpadrO['NRCORSEQPRAT'];
        $corAux     = $pratpadrO['NRCORAUXPRAT'];
        $container  = $pratpadrO['QTCONTAIPRAT'];
        $hora       = $pratpadrO['HRVALCONPRAT'];
        $nomeFant   = $pratpadrO['NMFANTASIAPR'];
        $qtCarb     = $pratpadrO['QTCARBOPRPAD'];
        $qtLip      = $pratpadrO['QTLIPIDPRPAD'];
        $qtProt     = $pratpadrO['QTPROTEPRPAD'];
        $qtCal      = $pratpadrO['QTCALORPRPAD'];
        $qtAlc      = $pratpadrO['QTALCOOPRPAD'];
        $qtMin      = $pratpadrO['VRPEMINPADR'];
        $qtAmost    = $pratpadrO['QTAMOSTRPADR'];
        $qtLim      = $pratpadrO['QTLIMSEGPADR'];
        $idFinal    = $pratpadrO['IDFINALPADR'];
        $cdmediacase = $pratpadrO['CDMEDICASE'];
        $qtmedicas   = $pratpadrO['QTMEDICASEPRATPADR'];
        $idativo     = $pratpadrO['IDATIVO'];
        $dsprato     = $pratpadrO['DSPRATO'];
        $dtinativauto = $pratpadrO['DTINATIVAUTO'];
      break;
      case 'SERVICO':
        $cor         = $pratpadrO['NRCORPRISERV'];
        $quantidade  = $pratpadrO['QTPADRAOSERV'];
        $corSeq      = $pratpadrO['NRCORSEQSERV'];
        $corAux      = $pratpadrO['NRCORAUXSERV'];
        $container   = $pratpadrO['QTCONTAISERV'];
        $hora        = $pratpadrO['HRVALCONSERV'];
        $nomeFant    = $pratpadrO['NMFANTASIASE'];
        $qtCarb      = $pratpadrO['QTCARBOPRSER'];
        $qtLip       = $pratpadrO['QTLIPIDPRSER'];
        $qtProt      = $pratpadrO['QTPROTEPRSER'];
        $qtCal       = $pratpadrO['QTCALORPRSER'];
        $qtAlc       = $pratpadrO['QTALCOOPRSER'];
        $qtMin       = $pratpadrO['VRPEMINSERV'];
        $qtAmost     = $pratpadrO['QTAMOSTRSERV'];
        $qtLim       = $pratpadrO['QTLIMSEGSERV'];
        $idFinal     = $pratpadrO['IDFINALSERV'];
        $cdmediacase = $pratpadrO['CDMEDICASE'];
        $qtmedicas   = $pratpadrO['QTMEDICASEPRATSERV'];
        $idativo     = $pratpadrO['IDATIVO'];
        $dsprato     = $pratpadrO['DSPRATO'];
        $dtinativauto = $pratpadrO['DTINATIVAUTO'];
      break;
      case 'LOCAL':
        $cor        = $pratpadrO['NRCORPRIFILI'];
        $quantidade = $pratpadrO['QTPADRAOFILI'];
        $corSeq     = $pratpadrO['NRCORSEQFILI'];
        $corAux     = $pratpadrO['NRCORAUXFILI'];
        $container  = $pratpadrO['QTCONTAIFILI'];
        $hora       = $pratpadrO['HRVALCONFILI'];
        $nomeFant   = $pratpadrO['NMFANTASIAPF'];
        $qtCarb     = $pratpadrO['QTCARBOPRFIL'];
        $qtLip      = $pratpadrO['QTLIPIDPRFIL'];
        $qtProt     = $pratpadrO['QTPROTEPRFIL'];
        $qtCal      = $pratpadrO['QTCALORPRFIL'];
        $qtAlc      = $pratpadrO['QTALCOOPRFIL'];
        $qtMin      = $pratpadrO['VRPEMINFILI'];
        $qtAmost    = $pratpadrO['QTAMOSTRFILI'];
        $qtLim      = $pratpadrO['QTLIMSEGFILI'];
        $idFinal    = $pratpadrO['IDFINALFILI'];
        $cdmediacase = $pratpadrO['CDMEDICASE'];
        $qtmedicas   = $pratpadrO['QTMEDICASEPRATFILI'];
        $idativo     = $pratpadrO['IDATIVO'];
        $dsprato     = $pratpadrO['DSPRATO'];
        $dtinativauto = $pratpadrO['DTINATIVAUTO'];
      break;
      case 'TIPOCARD':
        $cor        = $pratpadrO['NRCORPRIPRATTP'];
        $quantidade = $pratpadrO['QTPADRAOPRATTP'];
        $corSeq     = $pratpadrO['NRCORSEQPRATTP'];
        $corAux     = $pratpadrO['NRCORAUXPRATTP'];
        $container  = $pratpadrO['QTCONTAIPRATTP'];
        $hora       = $pratpadrO['HRVALCONPRATTP'];
        $nomeFant   = $pratpadrO['NMFANTASIAPRTP'];
        $qtCarb     = $pratpadrO['QTCARBOPRPADTP'];
        $qtLip      = $pratpadrO['QTLIPIDPRPADTP'];
        $qtProt     = $pratpadrO['QTPROTEPRPADTP'];
        $qtCal      = $pratpadrO['QTCALORPRPADTP'];
        $qtAlc      = $pratpadrO['QTALCOOPRPADTP'];
        $qtMin      = $pratpadrO['VRPEMINPADRTP'];
        $qtAmost    = $pratpadrO['QTAMOSTRPADRTP'];
        // $qtLim      = $pratpadrO['QTAMOSTRPADRTP'];
        $idativo    = $pratpadrO['IDATIVO'];
        $dsprato     = $pratpadrO['DSPRATO'];
        $dtinativauto = $pratpadrO['DTINATIVAUTO'];
      break;
    }
    $code = $this->newCode->getCodeByTableName(strtoupper($dataSourceDestino), $this->utilities->getNrOrg());
    
    if ($tpImportacao !== 'SOBREPOR') { //acrescentar
      $prodProd = null;
      $idFinal = 'M';
      $idProdChill = 'N';
      $qtLim = '0';
      $idTpProdChill = 'NENHUM';
    }
    
    $this->insereDadosPrato(
      $cdFilAuxPratoDestino, $pratoDestino, $filialD, $servicoD, $cor, 
      $corSeq, $corAux, $quantidade,  $container, $hora, $nomeFant, $qtCarb, $qtLip, $qtProt,
      $qtCal, $qtAlc, $qtMin, $qtAmost, $prodProd, $qtLim, $idProdChill,
      $idTpProdChill, $idFinal, $cdmediacase, $qtmedicas,
      $this->utilities->getNrOrg(), $cdregiaoDestino, $nrpadraoqualidadeDestino, $tipocardD, $code, 
      $cdfilcentpme, $idativo, $dsprato, $dtinativauto
    );
  }
  
  public function insereDadosPrato (
    $filAuxPrat, $prato, $filial, $servico, $corPri, $corSeq, $corAux,
    $quantidade, $container, $hora, $nomeFant, $qtCarb, $qtLip, $qtProt,
    $qtCal, $qtAlc, $qtMin, $qtAmost, $prodProd, $qtLim, $idProdChill,
    $idTpProdChill, $idFinal, $cdmediacase, $qtmedicas, $nrorg, $cdregiao = null, 
    $nrpadraoqualidade = null, $tipocardD, $code = null, $cdfilcentpme, $idativo, 
    $dsprato, $dtinativauto) {

    if ($servico) {
      $dadosPratInserir = array(
        'NRORG'              => $nrorg,
        '__is_new'           => true,
        'CDFILAUXPRAT'       => $filAuxPrat,
        'CDPRATO'            => $prato,
        'CDFILIAL'           => $filial,
        'CDSERVFILI'         => $servico,
        'CDTIPOCARD'         => $tipocardD,
        'NRCORPRISERV'       => $corPri,
        'NRCORSEQSERV'       => $corSeq,
        'NRCORAUXSERV'       => $corAux,
        'QTPADRAOSERV'       => $quantidade,
        'QTCONTAISERV'       => $container,
        'HRVALCONSERV'       => $hora,
        'NMFANTASIASE'       => $nomeFant,
        'QTCARBOPRSER'       => $qtCarb,
        'QTLIPIDPRSER'       => $qtLip,
        'QTPROTEPRSER'       => $qtProt,
        'QTCALORPRSER'       => $qtCal,
        'QTALCOOPRSER'       => $qtAlc,
        'VRPEMINSERV'        => $qtMin,
        'QTAMOSTRSERV'       => $qtAmost,
        'CDPRODPRODUCAO'     => $prodProd,
        'QTLIMSEGSERV'       => $qtLim,
        'IDPRODCHILL'        => $idProdChill,
        'IDTPPRODCHILL'      => $idTpProdChill,
        'IDFINALSERV'        => $idFinal,
        'CDMEDICASE'         => $cdmediacase,
        'QTMEDICASEPRATSERV' => $qtmedicas,
        'IDATIVO'            => $idativo,
        'DSPRATO'            => $dsprato,
        'DTINATIVAUTO'       => $dtinativauto
      );

      $tabela = "pratserv";
    } else if ($nrpadraoqualidade) {
      if ($cdregiao) {
        $dadosPratInserir = array(
          'NRORG'             => $nrorg,
          '__is_new'          => true,
          'CDFILAUXPRAT'      => $filAuxPrat,
          'CDPRATO'           => $prato,
          'NRPRATREGIAO'      => $code,
          'NRPADRAOQUALIDADE' => $nrpadraoqualidade,
          'CDREGIAO'          => $cdregiao,
          'NRCORPRIREGIAO'    => $corPri,
          'QTPADRAOREGIAO'    => $quantidade,
        'DTINATIVAUTO' => $dtinativauto
        );
        
        $tabela = "pratregiao";
      } else {
        $dadosPratInserir = array(
          'NRORG'             => $nrorg,
          '__is_new'          => true,
          'CDFILAUXPRAT'      => $filAuxPrat,
          'CDPRATO'           => $prato,
          'NRPRATPADQUALI'    => $code,
          'NRPADRAOQUALIDADE' => $nrpadraoqualidade,
          'NRCORPRIPADQ'      => $corPri,
          'QTPADRAOPADQ'      => $quantidade,
        'DTINATIVAUTO' => $dtinativauto
        );

        $tabela = "pratpadquali";
      }
    } else if ($filial) {
      $dadosPratInserir = array(
        'NRORG'              => $nrorg,
        '__is_new'           => true,
        'CDFILAUXPRAT'       => $filAuxPrat,
        'CDPRATO'            => $prato,
        'CDFILIAL'           => $filial,
        'NRCORPRIFILI'       => $corPri,
        'NRCORSEQFILI'       => $corSeq,
        'NRCORAUXFILI'       => $corAux,
        'QTPADRAOFILI'       => $quantidade,
        'QTCONTAIFILI'       => $container,
        'HRVALCONFILI'       => $hora,
        'NMFANTASIAPF'       => $nomeFant,
        'QTCARBOPRFIL'       => $qtCarb,
        'QTLIPIDPRFIL'       => $qtLip,
        'QTPROTEPRFIL'       => $qtProt,
        'QTCALORPRFIL'       => $qtCal,
        'QTALCOOPRFIL'       => $qtAlc,
        'VRPEMINFILI'        => $qtMin,
        'QTAMOSTRFILI'       => $qtAmost,
        'CDPRODPRODUCAO'     => $prodProd,
        'QTLIMSEGFILI'       => $qtLim,
        'IDPRODCHILL'        => $idProdChill,
        'IDTPPRODCHILL'      => $idTpProdChill,
        'IDFINALFILI'        => $idFinal,
        'CDMEDICASE'         => $cdmediacase,
        'QTMEDICASEPRATFILI' => $qtmedicas,
        'IDATIVO'            => $idativo,
        'DSPRATO'            => $dsprato,
        'DTINATIVAUTO' => $dtinativauto
      );
      $tabela = "pratfili";

    } else if ($tipocardD) {
      $dadosPratInserir = array(
        'NRORG' => $nrorg,
        '__is_new' => true,
        'CDFILAUXPRAT' => $filAuxPrat,
        'CDPRATO' => $prato,
        'CDTIPOCARD' => $tipocardD,
        'NRCORPRIPRATTP' => $corPri,
        'NRCORSEQPRAT' => $corSeq,
        'NRCORAUXPRAT' => $corAux,
        'QTPADRAOPRATTP' => $quantidade,
        'QTCONTAIPRATTP' => $container,
        'HRVALCONPRATTP' => $hora,
        'NMFANTASIAPRTP' => $nomeFant,
        'CDFILCENTPME' => $cdfilcentpme,
        'QTCARBOPRPAD' => $qtCarb,
        'QTLIPIDPRPAD' => $qtLip,
        'QTPROTEPRPAD' => $qtProt,
        'QTCALORPRPAD' => $qtCal,
        'QTALCOOPRPAD' => $qtAlc,
        'VRPEMINPADRTP' => $qtMin,
        'QTAMOSTRPADRTP' => $qtAmost,
        'IDATIVO'            => $idativo,
        'DSPRATO'            => $dsprato,
        'QTLIMSEGPADR' => $qtLim,
        'DTINATIVAUTO' => $dtinativauto
      );
        $tabela = "prattpcard";
    } else {
      $dadosPratInserir = array(
        'NRORG' => $nrorg,
        '__is_new' => true,
        'CDFILAUXPRAT' => $filAuxPrat,
        'CDPRATO' => $prato,
        'NRCORPRIPRAT' => $corPri,
        'NRCORSEQPRAT' => $corSeq,
        'NRCORAUXPRAT' => $corAux,
        'QTPADRAOPRAT' => $quantidade,
        'QTCONTAIPRAT' => $container,
        'HRVALCONPRAT' => $hora,
        'NMFANTASIAPR' => $nomeFant,
        'QTCARBOPRPAD' => $qtCarb,
        'QTLIPIDPRPAD' => $qtLip,
        'QTPROTEPRPAD' => $qtProt,
        'QTCALORPRPAD' => $qtCal,
        'QTALCOOPRPAD' => $qtAlc,
        'VRPEMINPADR' => $qtMin,
        'QTAMOSTRPADR' => $qtAmost,
        'CDPRODPRODUCAO' => $prodProd,
        'QTLIMSEGPADR' => $qtLim,
        'IDPRODCHILL' => $idProdChill,
        'IDTPPRODCHILL' => $idTpProdChill,
        'IDFINALPADR' => $idFinal,
        'CDMEDICASE' => $cdmediacase,
        'QTMEDICASEPRATPADR' => $qtmedicas,
        'IDATIVO'            => $idativo,
        'DSPRATO'            => $dsprato,
        'DTINATIVAUTO' => $dtinativauto
      );

      $tabela = "pratpadr";
    }
    $requestInsertDadosPrato = new DTO\Request\Row($dadosPratInserir, '', '', '');
    $dadosPratInserir = $this->crudService->getRowsToSave($requestInsertDadosPrato, $tabela);
    
    $this->crudService->save($tabela, $dadosPratInserir);
  }

  private function setProperties(&$row, $typeFieldVR, $typeFieldQT, $typeFieldSEG) {
    $row['VRPEFATCOC'.$typeFieldVR] = $row['VRPEFATCOC'];
    $row['VRPEFATCOC'.$typeFieldVR.'AP'] = $row['VRPEFATCOCAP'];
    
    $row['VRPEFATCOR'.$typeFieldVR] = $row['VRPEFATCOR'];
    $row['VRPEFATCOR'.$typeFieldVR.'AP'] = $row['VRPEFATCORAP'];

    $row['QTBRUTA'.$typeFieldVR] = $row['QTBRUTA'];
    $row['QTPROD'.$typeFieldQT] = $row['QTPRODPRAT'];

    $row['QTBRUTA'.$typeFieldVR.'UNR'] = $row['QTBRUTAUNR'];
    if ($typeFieldVR === 'PRTP') $row['QTBRUTAPRUNRTP'] = $row['QTBRUTAUNR'];

    $row['QTCALCNUTR'.$typeFieldVR] = $row['QTCALCNUTR'];
    $row['QTUNIDEST'.$typeFieldVR] = $row['QTUNIDEST'];

    $row['HRTEMPPREP'.$typeFieldVR] = $row['HRTEMPPREP'];
    $row['IDPRODBASE'.$typeFieldVR] = $row['IDPRODBASE'];
    $row['VRPEFATNUT'.$typeFieldVR] = $row['VRPEFATNUT'];
    $row['IDQTDEFIX'.$typeFieldVR] = $row['IDQTDEFIX'];

    
    $row['QTLIMSEG'.$typeFieldSEG] = empty($row['QTLIMSEG']) ? null : $row['QTLIMSEG'];
    $row['QTCOMPLPROD'.$typeFieldSEG] = empty($row['QTCOMPLPROD']) ? 0 : $row['QTCOMPLPROD'];
    $row['IDTPREQPROD'.$typeFieldSEG] = empty($row['IDTPREQPROD']) ? 'P' : $row['IDTPREQPROD'];
    $row['IDUTCOMPENTDIR'.substr($typeFieldSEG,0,1)] = empty($row['IDUTCOMPENTDIR']) ? 'N' : $row['IDUTCOMPENTDIR'];
  }

  public function deleteRecipe($firstRow, $filterProduct = false) {
    $query = 'DELETE FROM RECEPADR WHERE CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
    
    $params = array(
      'P_CDPRATDEST'      => $firstRow['CDPRATO'],
      'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT']
    );
    
    if($firstRow['RECIPEDEST'] == 'TIPOCARD'){
      $query = 'DELETE FROM RECETPCARD WHERE CDFILCENTPME = :P_CDFILCENTPMEDEST AND CDTIPOCARD = :P_CDTIPOCARDDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDFILCENTPMEDEST'=> $firstRow['CDFILCENTPME'],
        'P_CDTIPOCARDDEST'  => $firstRow['CDTIPOCARD']
      );
    }
    else if($firstRow['RECIPEDEST'] == 'LOCAL'){
      $query = 'DELETE FROM RECEFILI WHERE CDFILIAL = :P_CDFILIALDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDFILIALDEST'    => $firstRow['CDFILIAL']
      );
    }
    else if($firstRow['RECIPEDEST'] == 'SERVICO'){
      $query = 'DELETE FROM RECESERV WHERE CDFILIAL = :P_CDFILIALDEST AND CDSERVFILI = :P_CDSERVFILIDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDFILIALDEST'    => $firstRow['CDFILIAL'],
        'P_CDSERVFILIDEST'  => $firstRow['CDSERVFILI']
      );
    } else if ($firstRow['RECIPEDEST'] == 'PADRAOQUALI') {
      $query = 'DELETE FROM RECEPADQUALI WHERE NRPADRAOQUALIDADE = :P_NRPADRAOQUALIDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        // 'P_CDFILIALDEST'    => $firstRow['CDFILIAL'],
        'P_NRPADRAOQUALIDEST' => $firstRow['NRPADRAOQUALIDADE']
      );
    }  else if ($firstRow['RECIPEDEST'] == 'REGIAO') {
      $query = 'DELETE FROM RECEREGIAO WHERE CDREGIAO = :P_CDREGIAODEST AND NRPADRAOQUALIDADE = :P_NRPADRAOQUALIDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDREGIAODEST'    => $firstRow['CDREGIAO'],
        'P_NRPADRAOQUALIDEST' => $firstRow['NRPADRAOQUALIDADE']
      );
    } 
    
    if ($filterProduct === true) {
      $query .= " AND CDPRODUTO = :P_CDPRODUTO";
      $params['P_CDPRODUTO'] = $firstRow['CDPRODUTO'];
    }
    $stmt = $this->connection->prepare($query);
    $stmt->execute($params);
  }
  
  public function deletePlate($firstRow) {
    $query = 'DELETE FROM PRATPADR WHERE CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
    $params = array(
      'P_CDPRATDEST'      => $firstRow['CDPRATO'],
      'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT']
    );

    if($firstRow['RECIPEDEST'] == 'TIPOCARD'){
      $query = 'DELETE FROM PRATTPCARD WHERE CDFILCENTPME = :P_CDFILCENTPMEDEST AND CDTIPOCARD = :P_CDTIPOCARDDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDFILCENTPMEDEST'=> $firstRow['CDFILCENTPME'],
        'P_CDTIPOCARDDEST'  => $firstRow['CDTIPOCARD']
      );
    }
    else if($firstRow['RECIPEDEST'] == 'LOCAL'){
      $query = 'DELETE FROM PRATFILI WHERE CDFILIAL = :P_CDFILIALDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDFILIALDEST'    => $firstRow['CDFILIAL']
      );
    }
    else if($firstRow['RECIPEDEST'] == 'SERVICO'){
      $query = 'DELETE FROM PRATSERV WHERE CDFILIAL = :P_CDFILIALDEST AND CDSERVFILI = :P_CDSERVFILIDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDFILIALDEST'    => $firstRow['CDFILIAL'],
        'P_CDSERVFILIDEST'  => $firstRow['CDSERVFILI']
      );
    } else if($firstRow['RECIPEDEST'] == 'PADRAOQUALI') {
      $query = 'DELETE FROM PRATPADQUALI WHERE NRPADRAOQUALIDADE = :P_NRPADRAOQUALIDADEDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_NRPADRAOQUALIDADEDEST' => $firstRow['NRPADRAOQUALIDADE']
      );
    } else if($firstRow['RECIPEDEST'] == 'REGIAO') {
      $query = 'DELETE FROM PRATREGIAO WHERE CDREGIAO = :P_CDREGIAODEST AND NRPADRAOQUALIDADE = :P_NRPADRAOQUALIDADEDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDREGIAODEST'    => $firstRow['CDREGIAO'],
        'P_NRPADRAOQUALIDADEDEST' => $firstRow['NRPADRAOQUALIDADE']
      );
    } else if($firstRow['RECIPEDEST'] == 'GRAMAGEM') {
      $query = 'DELETE FROM PRATOGRAMAG WHERE CDFILIAL = :P_CDFILIALDEST AND CDSERVFILI = :P_CDSERVFILIDEST AND CDPRATO = :P_CDPRATDEST AND CDFILAUXPRAT = :P_CDFILAUXDEST';
      $params = array(
        'P_CDPRATDEST'      => $firstRow['CDPRATO'],
        'P_CDFILAUXDEST'    => $firstRow['CDFILAUXPRAT'],
        'P_CDFILIALDEST'    => $firstRow['CDFILIAL'],
        'P_CDSERVFILIDEST'  => $firstRow['CDSERVFILI']
      );
    }
    $this->connection->prepare($query)->execute($params);
  }
  
  public function updatePlate($firstRow, $dest) {
    $origem = $firstRow['ORIGEM'];
    
    if (isset($firstRow['CDTIPOCARD']) == false) $firstRow['CDTIPOCARD'] = null;
    if (isset($firstRow['CDSERVFILI']) == false) $firstRow['CDSERVFILI'] = null;
    
    $query = "SELECT :P_CDPRATDEST CDPRATO, :P_CDFILAUXDEST CDFILAUXPRAT, :P_CDFILCENTPMEDEST CDFILCENTPME, :P_CDTIPOCARDDEST CDTIPOCARD, :P_CDFILIDEST CDFILIAL, :P_CDSERVDEST CDSERVFILI, NRCORPRIPRAT NRCORPRI, NRCORSEQPRAT NRCORSEQ, NRCORAUXPRAT NRCORAUX, QTPADRAOPRAT QTPADRAO, QTCONTAIPRAT QTCONTAI,
                  HRVALCONPRAT HRVALCON, NMFANTASIAPR NMFANTASIA, QTCARBOPRPAD QTCARBOPR, QTLIPIDPRPAD QTLIPIDPR, QTPROTEPRPAD QTPROTEPR, QTCALORPRPAD QTCALORPR, QTALCOOPRPAD QTALCOOPR, VRPEMINPADR VRPEMIN, QTAMOSTRPADR QTAMOSTR, CDPRODPRODUCAO, QTLIMSEGPADR QTLIM, IDPRODCHILL, IDTPPRODCHILL, IDFINALPADR IDFINAL
              FROM PRATPADR WHERE (CDPRATO = :P_CDPRATORIG) AND (CDFILAUXPRAT  = :P_CDFILAUXORIG) AND :P_IDTIPORECE = 'PADRAO'
              UNION ALL
              SELECT :P_CDPRATDEST CDPRATO, :P_CDFILAUXDEST CDFILAUXPRAT, :P_CDFILCENTPMEDEST CDFILCENTPME, :P_CDTIPOCARDDEST CDTIPOCARD, :P_CDFILIDEST CDFILIAL, :P_CDSERVDEST CDSERVFILI, NRCORPRIPRATTP NRCORPRI, NRCORSEQPRATTP NRCORSEQ, NRCORAUXPRATTP NRCORAUX, QTPADRAOPRATTP QTPADRAO, QTCONTAIPRATTP QTCONTAI,
                  HRVALCONPRATTP HRVALCON, NMFANTASIAPRTP NMFANTASIA, QTCARBOPRPADTP QTCARBOPR, QTLIPIDPRPADTP QTLIPIDPR, QTPROTEPRPADTP QTPROTEPR, QTCALORPRPADTP QTCALORPR, QTALCOOPRPADTP QTALCOOPR, VRPEMINPADRTP VRPEMIN, QTAMOSTRPADRTP QTAMOSTR, NULL CDPRODPRODUCAO, NULL QTLIM, NULL IDPRODCHILL, NULL IDTPPRODCHILL, NULL IDFINAL
              FROM PRATTPCARD WHERE (CDPRATO = :P_CDPRATORIG) AND (CDFILAUXPRAT = :P_CDFILAUXORIG) AND (CDFILCENTPME = :P_CDFILCENTPMEORIG) AND (CDTIPOCARD = :P_CDTIPOCARDORIG) AND :P_IDTIPORECE = 'TIPOCARD'
              UNION ALL
              SELECT :P_CDPRATDEST CDPRATO, :P_CDFILAUXDEST CDFILAUXPRAT, :P_CDFILCENTPMEDEST CDFILCENTPME, :P_CDTIPOCARDDEST CDTIPOCARD, :P_CDFILIDEST CDFILIAL, :P_CDSERVDEST CDSERVFILI, NRCORPRIFILI NRCORPRI, NRCORSEQFILI NRCORSEQ, NRCORAUXFILI NRCORAUX, QTPADRAOFILI QTPADRAO, QTCONTAIFILI QTCONTAI,
                  HRVALCONFILI HRVALCON, NMFANTASIAPF NMFANTASIA, QTCARBOPRFIL QTCARBOPR, QTLIPIDPRFIL QTLIPIDPR, QTPROTEPRFIL QTPROTEPR, QTCALORPRFIL QTCALORPR, QTALCOOPRFIL QTALCOOPR, VRPEMINFILI VRPEMIN, QTAMOSTRFILI QTAMOSTR, CDPRODPRODUCAO, QTLIMSEGFILI QTLIM, IDPRODCHILL, IDTPPRODCHILL, IDFINALFILI IDFINAL
              FROM PRATFILI WHERE (CDPRATO = :P_CDPRATORIG) AND (CDFILAUXPRAT = :P_CDFILAUXORIG) AND (CDFILIAL = :P_CDFILIORIG) AND :P_IDTIPORECE = 'LOCAL'
              UNION ALL
              SELECT :P_CDPRATDEST CDPRATO, :P_CDFILAUXDEST CDFILAUXPRAT, :P_CDFILCENTPMEDEST CDFILCENTPME, :P_CDTIPOCARDDEST CDTIPOCARD, :P_CDFILIDEST CDFILIAL, :P_CDSERVDEST CDSERVFILI, NRCORPRISERV NRCORPRI, NRCORSEQSERV NRCORSEQ, NRCORAUXSERV NRCORAUX, QTPADRAOSERV QTPADRAO, QTCONTAISERV QTCONTAI,
                  HRVALCONSERV HRVALCON, NMFANTASIASE NMFANTASIA, QTCARBOPRSER QTCARBOPR, QTLIPIDPRSER QTLIPIDPR, QTPROTEPRSER QTPROTEPR, QTCALORPRSER QTCALORPR, QTALCOOPRSER QTALCOOPR, VRPEMINSERV VRPEMIN, QTAMOSTRSERV QTAMOSTR, CDPRODPRODUCAO, QTLIMSEGSERV QTLIM, IDPRODCHILL, IDTPPRODCHILL, IDFINALSERV IDFINAL
              FROM PRATSERV WHERE (CDPRATO = :P_CDPRATORIG) AND (CDFILAUXPRAT = :P_CDFILAUXORIG) AND (CDFILIAL = :P_CDFILIORIG) AND (CDSERVFILI = :P_CDSERVORIG) AND :P_IDTIPORECE = 'SERVICO'
              UNION ALL
              SELECT :P_CDPRATDEST CDPRATO, :P_CDFILAUXDEST CDFILAUXPRAT, :P_CDFILCENTPMEDEST CDFILCENTPME, :P_CDTIPOCARDDEST CDTIPOCARD, :P_CDFILIDEST CDFILIAL, :P_CDSERVDEST CDSERVFILI, NRCORPRIPADQ   NRCORPRI, NULL NRCORSEQ, NULL NRCORAUX, QTPADRAOPADQ   QTPADRAO, 0 QTCONTAI,
                NULL HRVALCON, NULL NMFANTASIA, NULL QTCARBOPR, NULL QTLIPIDPR, NULL QTPROTEPR, NULL QTCALORPR, NULL QTALCOOPR, NULL VRPEMIN, NULL QTAMOSTR, NULL CDPRODPRODUCAO, NULL QTLIM, NULL IDPRODCHILL, NULL IDTPPRODCHILL, NULL IDFINAL
              FROM PRATPADQUALI WHERE ( CDPRATO = :P_CDPRATORIG ) AND ( CDFILAUXPRAT = :P_CDFILAUXORIG ) AND ( NRPADRAOQUALIDADE = :P_NRPADRAOQUALIDADEORIG ) AND :P_IDTIPORECE = 'PADRAOQUALI'
              UNION ALL 
              SELECT :P_CDPRATDEST CDPRATO, :P_CDFILAUXDEST CDFILAUXPRAT, :P_CDFILCENTPMEDEST CDFILCENTPME, :P_CDTIPOCARDDEST CDTIPOCARD, :P_CDFILIDEST CDFILIAL, :P_CDSERVDEST CDSERVFILI, NRCORPRIREGIAO   NRCORPRI, NULL NRCORSEQ, NULL NRCORAUX, QTPADRAOREGIAO   QTPADRAO, 0 QTCONTAI,
                NULL HRVALCON, NULL NMFANTASIA, NULL QTCARBOPR, NULL QTLIPIDPR, NULL QTPROTEPR, NULL QTCALORPR, NULL QTALCOOPR, NULL VRPEMIN, NULL QTAMOSTR, NULL CDPRODPRODUCAO, NULL QTLIM, NULL IDPRODCHILL, NULL IDTPPRODCHILL, NULL IDFINAL
              FROM PRATREGIAO WHERE ( CDPRATO = :P_CDPRATORIG ) AND ( CDFILAUXPRAT = :P_CDFILAUXORIG ) AND ( NRPADRAOQUALIDADE = :P_NRPADRAOQUALIDADEORIG ) AND (CDREGIAO = :P_CDREGIAO) AND :P_IDTIPORECE = 'REGIAO'";
    
    $params = array(
      'P_CDPRATORIG'  => $origem['CDPRATO'],
      'P_CDFILAUXORIG'=> $origem['CDFILAUXPRAT'],
      'P_CDFILCENTPMEORIG' => $origem['CDFILCENTPME'],
      'P_CDTIPOCARDORIG'  => $origem['CDTIPOCARD'],
      'P_CDFILIORIG' => $origem['CDFILIAL'],
      'P_CDSERVORIG'  => $origem['CDSERVFILI'],
      'P_CDPRATDEST'  => $firstRow['CDPRATO'],
      'P_CDFILAUXDEST'=> $firstRow['CDFILAUXPRAT'],
      'P_CDFILCENTPMEDEST' => $firstRow['CDFILCENTPME'],
      'P_CDTIPOCARDDEST'   => $firstRow['CDTIPOCARD'],
      'P_CDFILIDEST' => $firstRow['CDFILIAL'],
      'P_CDSERVDEST'  => $firstRow['CDSERVFILI'],
      'P_IDTIPORECE'  => $firstRow['TYPE'],
      'P_NRPADRAOQUALIDADEORIG' => $firstRow['NRPADRAOQUALIDADE'],
      'P_CDREGIAO' => $firstRow['CDREGIAO'],
    );

    $result = $this->connection->fetchAll($query, $params);
    if(!empty($result)) $this->insertPlateImport($result, $dest);
  }

  public function insertPlateImport($result, $dest){
    $params = array(
      'NRCORPRI' => $result[0]['NRCORPRI'],
      'NRCORSEQ' => $result[0]['NRCORSEQ'],
      'NRCORAUX' => $result[0]['NRCORAUX'],
      'QTPADRAO' => $result[0]['QTPADRAO'],
      'QTCONTAI' => $result[0]['QTCONTAI'],
      'HRVALCON' => $result[0]['HRVALCON'],
      'NMFANTASIA' => $result[0]['NMFANTASIA'],
      'QTCARBOPR' => $result[0]['QTCARBOPR'],
      'QTLIPIDPR' => $result[0]['QTLIPIDPR'],
      'QTPROTEPR' => $result[0]['QTPROTEPR'],
      'QTCALORPR' => $result[0]['QTCALORPR'],
      'QTALCOOPR' => $result[0]['QTALCOOPR'],
      'VRPEMIN' => $result[0]['VRPEMIN'],
      'QTAMOSTR' => $result[0]['QTAMOSTR'],
      'CDPRODPRODUCAO' => $result[0]['CDPRODPRODUCAO'],
      'QTLIM' => $result[0]['QTLIM'],
      'IDPRODCHILL' => $result[0]['IDPRODCHILL'],
      'IDTPPRODCHILL' => $result[0]['IDTPPRODCHILL'],
      'IDFINAL' => $result[0]['IDFINAL'],
    );    

    if ($dest == 'PADRAO'){
      $insert = "INSERT INTO PRATPADR (CDFILAUXPRAT, CDPRATO, NRCORPRIPRAT, NRCORSEQPRAT, NRCORAUXPRAT, QTPADRAOPRAT, QTCONTAIPRAT,
                    HRVALCONPRAT, NMFANTASIAPR,QTCARBOPRPAD, QTLIPIDPRPAD, QTPROTEPRPAD, QTCALORPRPAD, QTALCOOPRPAD, VRPEMINPADR, QTAMOSTRPADR, 
                    CDPRODPRODUCAO, QTLIMSEGPADR, IDPRODCHILL, IDTPPRODCHILL, IDFINALPADR)
                 VALUES (:CDFILAUXPRAT, :CDPRATO, :NRCORPRI, :NRCORSEQ, :NRCORAUX, :QTPADRAO, :QTCONTAI,
                    :HRVALCON, :NMFANTASIA, :QTCARBOPR, :QTLIPIDPR, :QTPROTEPR, :QTCALORPR, :QTALCOOPR, :VRPEMIN, :QTAMOSTR,
                    :CDPRODPRODUCAO, :QTLIM, :IDPRODCHILL, :IDTPPRODCHILL, :IDFINAL)";
      
      $paramsDest = array(
        'CDFILAUXPRAT' => $result[0]['CDFILAUXPRAT'],
        'CDPRATO' => $result[0]['CDPRATO']
      );
    } else if ($dest == 'TIPOCARD'){
      unset($params['CDPRODPRODUCAO']);
      unset($params['QTLIM']);
      unset($params['IDPRODCHILL']);
      unset($params['IDTPPRODCHILL']);
      unset($params['IDFINAL']);
      $insert = "INSERT INTO PRATTPCARD (CDFILCENTPME, CDTIPOCARD, CDFILAUXPRAT, CDPRATO, NRCORPRIPRATTP, NRCORSEQPRATTP, NRCORAUXPRATTP,QTPADRAOPRATTP, QTCONTAIPRATTP,
                    HRVALCONPRATTP, NMFANTASIAPRTP, QTCARBOPRPADTP, QTLIPIDPRPADTP, QTPROTEPRPADTP, QTCALORPRPADTP, QTALCOOPRPADTP,VRPEMINPADRTP, QTAMOSTRPADRTP)
                    VALUES ( :CDFILCENTPME, :CDTIPOCARD, :CDFILAUXPRAT, :CDPRATO, :NRCORPRI, :NRCORSEQ, :NRCORAUX, :QTPADRAO, :QTCONTAI,
                    :HRVALCON, :NMFANTASIA, :QTCARBOPR, :QTLIPIDPR, :QTPROTEPR, :QTCALORPR, :QTALCOOPR, :VRPEMIN, :QTAMOSTR)";
      $paramsDest = array(
        'CDFILCENTPME' => $result[0]['CDFILCENTPME'],
        'CDTIPOCARD' => $result[0]['CDTIPOCARD'],
        'CDFILAUXPRAT' => $result[0]['CDFILAUXPRAT'],
        'CDPRATO' => $result[0]['CDPRATO']
      );
    } else if ($dest == 'LOCAL'){
      $insert = "INSERT INTO PRATFILI (CDFILIAL, CDFILAUXPRAT, CDPRATO, NRCORPRIFILI, NRCORSEQFILI, NRCORAUXFILI, QTPADRAOFILI, QTCONTAIFILI,
                    HRVALCONFILI, NMFANTASIAPF, QTCARBOPRFIL, QTLIPIDPRFIL, QTPROTEPRFIL, QTCALORPRFIL, QTALCOOPRFIL, VRPEMINFILI, QTAMOSTRFILI,
                    CDPRODPRODUCAO, QTLIMSEGFILI, IDPRODCHILL, IDTPPRODCHILL, IDFINALFILI)
                    VALUES (:CDFILIAL, :CDFILAUXPRAT, :CDPRATO, :NRCORPRI, :NRCORSEQ, :NRCORAUX, :QTPADRAO, :QTCONTAI,
                    :HRVALCON, :NMFANTASIA, :QTCARBOPR, :QTLIPIDPR, :QTPROTEPR, :QTCALORPR, :QTALCOOPR, :VRPEMIN, :QTAMOSTR,
                    :CDPRODPRODUCAO, :QTLIM, :IDPRODCHILL, :IDTPPRODCHILL, :IDFINAL)";
      $paramsDest = array(
        'CDFILIAL' => $result[0]['CDFILIAL'],
        'CDFILAUXPRAT' => $result[0]['CDFILAUXPRAT'],
        'CDPRATO' => $result[0]['CDPRATO']
      );
    } else {
      $insert = "INSERT INTO PRATSERV (CDPRATO, CDFILAUXPRAT, CDFILIAL, CDSERVFILI, NRCORPRISERV, NRCORSEQSERV, NRCORAUXSERV, QTPADRAOSERV, QTCONTAISERV,
                HRVALCONSERV, NMFANTASIASE, QTCARBOPRSER, QTLIPIDPRSER, QTPROTEPRSER, QTCALORPRSER, QTALCOOPRSER, VRPEMINSERV, QTAMOSTRSERV,
                CDPRODPRODUCAO, QTLIMSEGSERV, IDPRODCHILL, IDTPPRODCHILL, IDFINALSERV)
                VALUES ( :CDPRATO, :CDFILAUXPRAT, :CDFILIAL, :CDSERVFILI, :NRCORPRI, :NRCORSEQ, :NRCORAUX, :QTPADRAO, :QTCONTAI,
                :HRVALCON, :NMFANTASIA, :QTCARBOPR, :QTLIPIDPR, :QTPROTEPR, :QTCALORPR, :QTALCOOPR, :VRPEMIN, :QTAMOSTR,
                :CDPRODPRODUCAO, :QTLIM, :IDPRODCHILL, :IDTPPRODCHILL, :IDFINAL)";
      $paramsDest = array(
        'CDPRATO' => $result[0]['CDPRATO'],  
        'CDFILAUXPRAT' => $result[0]['CDFILAUXPRAT'],
        'CDFILIAL' => $result[0]['CDFILIAL'],
        'CDSERVFILI' => $result[0]['CDSERVFILI']
      );
    }

    $params = array_merge($paramsDest, $params);
    $this->connection->prepare($insert)->execute($params);
  }
  
  public function returnReceitaPadrao(DTO\Request\Row $request, DTO\Response $response) {
	    $parameters = $request->getParameters();

	    $plate = $parameters['plate'];
	    $filAux = $parameters['filAux'];
	    $dataSourceName = 'receitaPadrao';
	    
	    // condição: CDPRATO, CDFILAUXPRAT
	    
	    $conditions = array(
	        array(
	            'columnName' => 'CDPRATO',
	            'operator' => '=',
	            'value' => $plate
	        ),
	        array(
	            'columnName' => 'CDFILAUXPRAT',
	            'operator' => '=',
	            'value' => $filAux
	        )
	    );	    
	    $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
	    $response->addDataSet(new DataSet("columnsToReturn", $result));
	}
	
	public function returnReceitaLocal(DTO\Request\Row $request, DTO\Response $response) {
	    $parameters = $request->getParameters();
	    $plate = $parameters['plate'];
	    $filAux = $parameters['filAux'];
	    $cdfilial = $parameters['cdfilial'];
	    $dataSourceName = 'receitaLocal';
	    
	    // condição: CDPRATO, CDFILAUXPRAT, CDFILIAL
	    
	    $conditions = array(
	        array(
	            'columnName' => 'CDPRATO',
	            'operator' => '=',
	            'value' => $plate
	        ),
	        array(
	            'columnName' => 'CDFILAUXPRAT',
	            'operator' => '=',
	            'value' => $filAux
	        ),
	        array(
	            'columnName' => 'CDFILIAL',
	            'operator' => '=',
	            'value' => $cdfilial
	        )
	    );
	    $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
	    $response->addDataSet(new DataSet("columnsToReturn", $result));
	}
	
	public function returnReceitaServico(DTO\Request\Row $request, DTO\Response $response) {
	    $parameters = $request->getParameters();
	    $plate = $parameters['plate'];
	    $filAux = $parameters['filAux'];
	    $cdfilial = $parameters['cdfilial'];
	    $cdserv = $parameters['cdserv'];
	    $dataSourceName = 'receitaServico';
	    
		// condição: CDPRATO, CDFILAUXPRAT, CDFILIAL, CDSERVFILI
	   
	    $conditions = array(
	        array(
	            'columnName' => 'CDPRATO',
	            'operator' => '=',
	            'value' => $plate
	        ),
	        array(
	            'columnName' => 'CDFILAUXPRAT',
	            'operator' => '=',
	            'value' => $filAux
	        ),
	        array(
	            'columnName' => 'CDFILIAL',
	            'operator' => '=',
	            'value' => $cdfilial
	        ),
	        array(
	            'columnName' => 'CDSERVFILI',
	            'operator' => '=',
	            'value' => $cdserv
	        )
	    );

	    $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
	    $response->addDataSet(new DataSet("columnsToReturn", $result));
	}
	
	public function returnReceitaTpCard(DTO\Request\Row $request, DTO\Response $response) {
	    $parameters = $request->getParameters();
	    $plate = $parameters['plate'];
	    $filAux = $parameters['filAux'];
	    $tipocard = $parameters['tipocard'];
	    $central = $parameters['central'];
	    $dataSourceName = 'receitaTpCard';
	    
	    // condição: CDPRATO, CDFILAUXPRAT, CDFILCENTPME, CDTIPOCARD

	    $conditions = array(
	        array(
	            'columnName' => 'P_CDPRATO',
	            'operator' => '=',
	            'value' => $plate
	        ),
	        array(
	            'columnName' => 'P_CDFILAUXPRAT',
	            'operator' => '=',
	            'value' => $filAux
	        ),
	        array(
	            'columnName' => 'P_CDFILCENTPME',
	            'operator' => '=',
	            'value' => $central
	        ),
	        array(
	            'columnName' => 'P_CDTIPOCARD',
	            'operator' => '=',
	            'value' => $tipocard
	        )
	    );
	    
	    $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
	    $response->addDataSet(new DataSet("columnsToReturn", $result));
	}
	
	public function returnReceitaPadraoQualidade(DTO\Request\Row $request, DTO\Response $response) {
	    $parameters = $request->getParameters();
	    $plate = $parameters['plate'];
	    $filAux = $parameters['filAux'];
	    $dataSourceName = 'receitaPadraoQualidade';
	  
	   // condição: CDPRATO, CDFILAUXPRAT, NRPADRAOQUALIDADE

	    $conditions = array(
	        array(
	            'columnName' => 'CDPRATO',
	            'operator' => '=',
	            'value' => $plate
	        ),
	        array(
	            'columnName' => 'CDFILAUXPRAT',
	            'operator' => '=',
	            'value' => $filAux
	        ),
	        array(
	            'columnName' => 'NRPADRAOQUALIDADE',
	            'operator' => '=',
	            'value' => $parameters['NRPADRAOQUALIDADE']
	        )	      
	    );
	    $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
	    $response->addDataSet(new DataSet("columnsToReturn", $result));
	}

	public function returnReceitaRegiao(DTO\Request\Row $request, DTO\Response $response) {
	    $parameters = $request->getParameters();
	    $plate = $parameters['plate'];
	    $filAux = $parameters['filAux'];
	    $dataSourceName = 'receitaRegiao';
	  
		// condição: CDPRATO, CDFILAUXPRAT, NRPADRAOQUALIDADE, CDREGIAO
  
	    $conditions = array(
	        array(
	            'columnName' => 'CDPRATO',
	            'operator' => '=',
	            'value' => $plate
	        ),
	        array(
	            'columnName' => 'CDFILAUXPRAT',
	            'operator' => '=',
	            'value' => $filAux
	        ),
	        array(
	            'columnName' => 'NRPADRAOQUALIDADE',
	            'operator' => '=',
	            'value' => $parameters['NRPADRAOQUALIDADE']
	        ),
	        array(
	            'columnName' => 'CDREGIAO',
	            'operator' => '=',
	            'value' => $parameters['CDREGIAO']
	        )
	    );
	    $result = $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
	    $response->addDataSet(new DataSet("columnsToReturn", $result));
	}
  
	public function saveAjusteQuantidades(DTO\Request\Row $request, DTO\Response $response) {
    $ajusteQtd = $request->getParameters()['ajusteQtd'];

    $tipoReceita = $ajusteQtd['TIPORECEITA'];
    $operacao = $ajusteQtd['OPERACAO'];
    $qnt = $ajusteQtd['QUANTIDADE'];
    
    $dadosReceitaDestino = '';
            
		$newRequest = new DTO\Request\Row('',"","","");
		$newRequest->setParameter('plate', $ajusteQtd['CDPRATO']);
		$newRequest->setParameter('filAux', $ajusteQtd['CDFILAUXPRAT']);
		
    switch ($tipoReceita) {
      case 'R':
        $dadosReceitaDestino = 'receitaRegiao';
        
  			$newRequest->setParameter('NRPADRAOQUALIDADE', $ajusteQtd['NRPADRAOQUALIDADE']);
  			$newRequest->setParameter('CDREGIAO', $ajusteQtd['CDREGIAO']);
        
        $this->returnReceitaRegiao($newRequest, $response);
        $rows = $response->getDataSets()[0]->getRows();
        $rows = $this->validRows($rows, $dadosReceitaDestino);
        if (count($rows) == 0) $response->setError(new DTO\Response\Error('Operação Bloqueada! Sem receita cadastrada.', 1));
      
        foreach ($rows as $k => $row) {
          if ($row['IDQTDEFIXREGIAO'] == 'S') {
            unset($rows[$k]);
          } else {
        		$rows['__is_new'] = false;
          	if($operacao == 'M') {
          		$row['QTPRODRECREGIAO'] = $row['QTPRODRECREGIAO'] * $qnt;
        			$row['QTBRUTAREGIAOUNR'] = $row['QTBRUTAREGIAOUNR'] * $qnt;
          	} else {
          	  $row['QTPRODRECREGIAO'] = $row['QTPRODRECREGIAO'] / $qnt;
        			$row['QTBRUTAREGIAOUNR'] = $row['QTBRUTAREGIAOUNR'] / $qnt;
          	}
            $this->insertRecipeRegion($row);
          }
        }
      break;
      case 'Q':
        $dadosReceitaDestino = 'receitaPadraoQualidade';

  			$newRequest->setParameter('NRPADRAOQUALIDADE', $ajusteQtd['NRPADRAOQUALIDADE']);

        $this->returnReceitaPadraoQualidade($newRequest, $response);
        $rows = $response->getDataSets()[0]->getRows();
        $rows = $this->validRows($rows, $dadosReceitaDestino);
        if (count($rows) == 0) $response->setError(new DTO\Response\Error('Operação Bloqueada! Sem receita cadastrada.', 1));

        foreach ($rows as $k => $row) {
          if ($row['IDQTDEFIXPADQ'] == 'S') {
            unset($rows[$k]);
          } else {
        		$rows['__is_new'] = false;
          	if($operacao == 'M') {
          		$row['QTPRODRECPADQ'] = $row['QTPRODRECPADQ'] * floatval($qnt);
        			$row['QTBRUTAPADQUNR'] = $row['QTBRUTAPADQUNR'] * floatval($qnt);
          	} else {
          		$row['QTPRODRECPADQ'] = $row['QTPRODRECPADQ'] / floatval($qnt);
        			$row['QTBRUTAPADQUNR'] = $row['QTBRUTAPADQUNR'] / floatval($qnt);
          	}
            $this->insertRecipeQual($row);
          }
        }
      break;
      case 'P':
        $dadosReceitaDestino = 'receitaPadrao';
  			
        $this->returnReceitaPadrao($newRequest, $response);
        $rows = $response->getDataSets()[0]->getRows();
        $rows = $this->validRows($rows, $dadosReceitaDestino);
        if (count($rows) == 0) $response->setError(new DTO\Response\Error('Operação Bloqueada! Sem receita cadastrada.', 1));
        
        foreach ($rows as $k => $row) {
          if ($row['IDQTDEFIXPR'] == 'S') {
            unset($rows[$k]);
          } else {
        		$row['__is_new'] = false;
          	if($operacao == 'M') {
          		$row['QTPRODPRAT'] = $row['QTPRODPRAT'] * $qnt;
        			$row['QTBRUTAPRUNR'] =$row['QTBRUTAPRUNR'] * $qnt;
    					$row['QTBRUTAPR'] = $row['QTBRUTAPR'] * $qnt;
    					$row['QTCALCNUTRPR'] = $row['QTCALCNUTRPR'] * $qnt;
          	} else {
          		$row['QTPRODPRAT'] = $row['QTPRODPRAT'] / $qnt;
        			$row['QTBRUTAPRUNR'] = $row['QTBRUTAPRUNR'] / $qnt;
    				  $row['QTBRUTAPR']  = $row['QTBRUTAPR'] / $qnt;
    				  $row['QTCALCNUTRPR']  = $row['QTCALCNUTRPR'] / $qnt;
          	}
        
            $this->insertRecipeStandard($row);
          } 
        }
      break;
      case 'S':
        $dadosReceitaDestino = 'receitaServico';  
        
  			$newRequest->setParameter('cdfilial', $ajusteQtd['CDFILIAL']);
  			$newRequest->setParameter('cdserv', $ajusteQtd['CDSERVFILI']);
  			
        $this->returnReceitaServico($newRequest, $response);
        $rows = $response->getDataSets()[0]->getRows();
        $rows = $this->validRows($rows, $dadosReceitaDestino);
        if (count($rows) == 0) $response->setError(new DTO\Response\Error('Operação Bloqueada! Sem receita cadastrada.', 1));

        foreach ($rows as $k => $row) {
          if ($row['IDQTDEFIXSE'] == 'S') {
            unset($rows[$k]);
          } else {
        		$rows['__is_new'] = false;
          	if($operacao == 'M') {
          		$row['QTPRODRECSER'] = $row['QTPRODRECSER'] * $qnt;
        			$row['QTBRUTASEUNR'] = $row['QTBRUTASEUNR'] * $qnt;
    					$row['QTBRUTASE'] = $row['QTBRUTASE'] * $qnt;
					    $row['QTCALCNUTRSE'] = $row['QTCALCNUTRSE'] * $qnt;
          	} else {
        			$row['QTPRODRECSER'] = $row['QTPRODRECSER'] / $qnt;
        			$row['QTBRUTASEUNR'] = $row['QTBRUTASEUNR'] / $qnt;
    			  	$row['QTBRUTASE'] = $row['QTBRUTASE'] / $qnt;
					  	$row['QTCALCNUTRSE'] = $row['QTCALCNUTRSE'] / $qnt;	
          	}
          	
            $this->insertRecipeService($row);
          }
        }
    break;
    case 'L':
      $dadosReceitaDestino = 'receitaLocal';
			$newRequest->setParameter('cdfilial', $ajusteQtd['CDFILIAL']);

      $this->returnReceitaLocal($newRequest, $response);
      $rows = $response->getDataSets()[0]->getRows();
      $rows = $this->validRows($rows, $dadosReceitaDestino);
      if (count($rows) == 0) $response->setError(new DTO\Response\Error('Operação Bloqueada! Sem receita cadastrada.', 1));

      foreach ($rows as $k => $row) {
        if ($row['IDQTDEFIXLO'] == 'S') {
          unset($rows[$k]);
        } else {
      		$rows['__is_new'] = false;
        	if($operacao == 'M') {
        		$row['QTPRODRECLOC'] = $row['QTPRODRECLOC'] * $qnt;
    				$row['QTBRUTALOUNR'] = $row['QTBRUTALOUNR'] * $qnt;
  					$row['QTBRUTALO'] = $row['QTBRUTALO'] * $qnt;
  			  	$row['QTCALCNUTRLO'] = $row['QTCALCNUTRLO'] * $qnt;
        	} else {
        		$row['QTPRODRECLOC'] = $row['QTPRODRECLOC'] / $qnt;
      			$row['QTBRUTALOUNR'] = $row['QTBRUTALOUNR'] / $qnt;
  					$row['QTBRUTALO'] = $row['QTBRUTALO'] / $qnt;
  				  $row['QTCALCNUTRLO'] = $row['QTCALCNUTRLO'] / $qnt;	
        	}
          $this->insertRecipeLocal($row);
        }
      }
    break;
    case 'C':
      $dadosReceitaDestino = 'receitaTpCard';
      
			$newRequest->setParameter('tipocard', $ajusteQtd['CDTIPOCARD']);
			$newRequest->setParameter('central', $ajusteQtd['CDFILCENTPME']);
			

      $this->returnReceitaTpCard($newRequest, $response);
      $rows = $response->getDataSets()[0]->getRows();
      $rows = $this->validRows($rows, $dadosReceitaDestino);
          foreach ($rows as $k => $row) {
            if ($row['IDQTDEFIXPRTP'] == 'S') {
              unset($rows[$k]);
            } else {
          		$rows['__is_new'] = false;
            	if($operacao == 'M') {
            		$row['QTPRODPRATTP'] = $row['QTPRODPRATTP'] * $qnt;
        				$row['QTBRUTAPRUNRTP'] = $row['QTBRUTAPRUNRTP'] * $qnt;
        				$row['QTBRUTAPRTP'] = $row['QTBRUTAPRTP'] * $qnt;
        				$row['QTCALCNUTRPRTP'] = $row['QTCALCNUTRPRTP'] * $qnt;
            	} else {
            		$row['QTPRODPRATTP'] = $row['QTPRODPRATTP'] / $qnt;
          			$row['QTBRUTAPRUNRTP'] = $row['QTBRUTAPRUNRTP'] / $qnt;
          			$row['QTBRUTAPRTP'] = $row['QTBRUTAPRTP'] / $qnt;
          			$row['QTCALCNUTRPRTP'] = $row['QTCALCNUTRPRTP'] / $qnt;
            	}
              $this->insertRecipeTpCard($row);
            }
          }
      break;
    }
	}
	    
	// IMPORTAR FATOR CORREÇÃO
	
  public function importarFatorCorrecao(DTO\Request\Row $request, DTO\Response $response) {
    $row = $request->getRow();
    $value = $request->getParameters()['valoresFixos'];

    $tipoReceita = $value['TIPORECEITA'];
    
    $dadosReceitaDestino = '';
            
    $newRequest = new DTO\Request\Row('',"","","");
    $newRequest->setParameter('plate', $value['CDPRATO']);
    $newRequest->setParameter('filAux', $value['CDFILAUXPRAT']);
    
    switch ($tipoReceita) {
      case 'P':
          $dadosReceitaDestino = 'receitaPadrao';
          $this->returnReceitaPadrao($newRequest, $response);
          
          foreach ($row as $produto) {
            $produto['__is_new'] = false;
            $produto['VRPEFATCORPR'] = $produto['VRPEFATOCORR'];
            $produto['QTPRODPRAT'] = $produto['QTBRUTAPR'];
            if ($produto['VRPEFATCORPR'] > 0) {
              $produto['QTPRODPRAT'] = $produto['QTBRUTAPR'] - (($produto['QTBRUTAPR'] * $produto['VRPEFATCORPR']) / 100);
            }
            if ($produto['VRPEFATCOCPR'] > 0) {
              $produto['QTPRODPRAT'] = $produto['QTPRODPRAT'] + ($produto['QTPRODPRAT'] * ($produto['VRPEFATCOCPR'] / 100));
            } 
  				  $produto['QTCALCNUTRPR']  = $produto['QTPRODPRAT'];
            $this->insertRecipeStandard($produto);
          }
      break;
      case 'R':
          $dadosReceitaDestino = 'receitaRegiao';
          
          $newRequest->setParameter('NRPADRAOQUALIDADE', $value['NRPADRAOQUALIDADE']);
          $newRequest->setParameter('CDREGIAO', $value['CDREGIAO']);
          $this->returnReceitaRegiao($newRequest, $response);
  
          foreach ($row as $produto) {
            $produtos['__is_new'] = false;
        		$produto['VRPEFATCORREGIAO'] = $produto['VRPEFATOCORR'];
            $produto['QTPRODRECREGIAO'] = $produto['QTBRUTAREGIAOUNR'];
            if ($produto['VRPEFATCORREGIAO'] > 0) {
              $produto['QTPRODRECREGIAO'] = $produto['QTBRUTAREGIAOUNR'] - (($produto['QTBRUTAREGIAOUNR'] * $produto['VRPEFATCORREGIAO']) / 100);
            }
            if ($produto['VRPEFATCOCLOAP'] > 0) {
              $produto['QTPRODRECREGIAO'] = $produto['QTPRODRECREGIAO'] + ($produto['QTPRODRECREGIAO'] * ($produto['VRPEFATCOCREGIAO'] / 100));
            } 
            $this->insertRecipeRegion($produto);
          }
      break;
      case 'Q':
          $dadosReceitaDestino = 'receitaPadraoQualidade';
  
          $newRequest->setParameter('NRPADRAOQUALIDADE', $value['NRPADRAOQUALIDADE']);
          $this->returnReceitaPadraoQualidade($newRequest, $response);
  
          foreach ($row as $produto) {
            $produtos['__is_new'] = false;
        		// $produto['VRPEFATCORPADQ'] = 100 - $produto['VRPEFATCORPADQ'];
        		$produto['VRPEFATCORPADQ'] = $produto['VRPEFATCORPADQ'];
            $produto['QTPRODRECPADQ'] = $produto['QTPRODRECPADQ'];
            if ($produto['VRPEFATCORPADQ'] > 0) {
              $produto['QTPRODRECPADQ'] = $produto['QTBRUTAPADQUNR'] - (($produto['QTBRUTAPADQUNR'] * $produto['VRPEFATCORPADQ']) / 100);
            }
            if ($produto['VRPEFATCOCLOAP'] > 0) {
              $produto['QTPRODRECPADQ'] = $produto['QTPRODRECPADQ'] + ($produto['QTPRODRECPADQ'] * ($produto['VRPEFATCOCPADQ'] / 100));
            } 
            $this->insertRecipeQual($produto);
          }
      break;
      case 'S':
          $dadosReceitaDestino = 'receitaServico';  
          
          $newRequest->setParameter('cdfilial', $value['CDFILIAL']);
          $newRequest->setParameter('cdserv', $value['CDSERVFILI']);
          
          $this->returnReceitaServico($newRequest, $response);
  
          foreach ($row as $produto) {
            $produto['__is_new'] = false;
            $produto['VRPEFATCORSE'] = $produto['VRPEFATOCORR'];
            $produto['QTPRODRECSER'] = $produto['QTBRUTASE'];
            if ($produto['VRPEFATCORSE'] > 0) {
              $produto['QTPRODRECSER'] = $produto['QTBRUTASE'] - (($produto['QTBRUTASE'] * $produto['VRPEFATCORSE']) / 100);
            }
            if ($produto['VRPEFATCOCSE'] > 0) {
              $produto['QTPRODRECSER'] = $produto['QTPRODRECSER'] + ($produto['QTPRODRECSER'] * ($produto['VRPEFATCOCSE'] / 100));
            } 
  				  $produto['QTCALCNUTRSE']  = $produto['QTPRODRECSER'];
            $this->insertRecipeService($produto);
          }
      break;
      case 'L':
        $dadosReceitaDestino = 'receitaLocal';
        $newRequest->setParameter('cdfilial', $value['CDFILIAL']);
        $this->returnReceitaLocal($newRequest, $response);

        foreach ($row as $produto) {
          $produtos['__is_new'] = false;
      		$produto['VRPEFATCORLO'] = $produto['VRPEFATOCORR'];
          $produto['QTPRODRECLOC'] = $produto['QTBRUTALO'];
          if ($produto['VRPEFATCORLO'] > 0) {
            $produto['QTPRODRECLOC'] = $produto['QTBRUTALO'] - (($produto['QTBRUTALO'] * $produto['VRPEFATCORLO']) / 100);
          }
          if ($produto['VRPEFATCOCLO'] > 0) {
            $produto['QTPRODRECLOC'] = $produto['QTPRODRECLOC'] + ($produto['QTPRODRECLOC'] * ($produto['VRPEFATCOCLO'] / 100));
          } 
				  $produto['QTCALCNUTRLO'] = $produto['QTPRODRECLOC'];
          $this->insertRecipeLocal($produto);
        }
      break;
      case 'C':
          $dadosReceitaDestino = 'receitaTpCard';
          
          $newRequest->setParameter('tipocard', $value['CDTIPOCARD']);
          $newRequest->setParameter('central', $value['CDFILCENTPME']);
          $this->returnReceitaTpCard($newRequest, $response);
  
          foreach ($row as $produto) {
            $produtos['__is_new'] = false;
         		$produto['VRPEFATCORPRTP'] = $produto['VRPEFATOCORR'];
            $produto['QTPRODPRATTP'] = $produto['QTBRUTAPRTP'];
            if ($produto['VRPEFATCORPRTP'] > 0) {
              $produto['QTPRODPRATTP'] = $produto['QTBRUTAPRTP'] - (($produto['QTBRUTAPRTP'] * $produto['VRPEFATCORPRTP']) / 100);
            }
            if ($produto['VRPEFATCOCPRTP'] > 0) {
              $produto['QTPRODPRATTP'] = $produto['QTPRODPRATTP'] + ($produto['QTPRODPRATTP'] * ($produto['VRPEFATCOCPRTP'] / 100));
            } 
  				  $produto['QTCALCNUTRPRTP'] = $produto['QTPRODPRATTP'];
            $this->insertRecipeTpCard($produto);
          }
      break;
    }
  }
  
  public function returnRecipePadrao($cdprato, $cdFilAuxPrat, $cdproduto = null) {
    $params = array(
			"CDPRATO"      => $cdprato,
			"CDFILAUXPRAT" => $cdFilAuxPrat
		);
		
    if (!empty($cdproduto)) {
      $whereProdLine = "AND RP.CDPRODUTO = :CDPRODUTO ";
      $params['CDPRODUTO'] = $cdproduto;
    } else $whereProdLine = "";
    
		$sql = "SELECT RP.CDPRATO, RP.CDFILAUXPRAT, RP.CDPRODUTO, RP.IDQTDEFIXPR, NVL(RP.SGUNIDADE, P.SGUNIDADE) AS SGUNIDADE, RP.QTPRODPRAT, RP.QTBRUTAPRUNR, RP.QTBRUTAPR, RP.QTCALCNUTRPR, RP.VRPEFATCOCPR, RP.VRPEFATCORPR, RP.HRTEMPPREPPR, RP.QTUNIDESTPR, RP.IDPRODBASEPR, RP.CDAPRERECE, RP.VRPEFATNUTPR, RP.QTLIMSEGPADR, RP.IDUTCOMPENTDIRP, RP.QTCOMPLPRODPADR, RP.IDTPREQPRODPADR, RP.NRORG, RP.VRPERCDEGELO FROM RECEPADR RP INNER JOIN PRODUTO    P ON P.CDPRODUTO = RP.CDPRODUTO WHERE RP.CDPRATO = :CDPRATO AND RP.CDFILAUXPRAT = :CDFILAUXPRAT ".$whereProdLine." ORDER BY P.CDARVPROD";
    
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function returnRecipeLocal($cdprato, $cdFilAuxPrat, $cdfilial, $cdproduto = null) {
		$params = array(
			"CDPRATO"      => $cdprato,
			"CDFILAUXPRAT" => $cdFilAuxPrat,
			"CDFILIAL"     => $cdfilial
		);
		
		if (!empty($cdproduto)) {
      $whereProdLine = "AND RF.CDPRODUTO = :CDPRODUTO ";
      $params['CDPRODUTO'] = $cdproduto;
    } else $whereProdLine = "";
		
		$sql = "SELECT RF.CDFILAUXPRAT, RF.CDPRATO, RF.CDFILIAL, RF.CDPRODUTO, RF.QTPRODRECLOC, RF.VRPEFATCOCLO, RF.VRPEFATCORLO, RF.HRTEMPPREPLO, NVL(RF.SGUNIDADE, P.SGUNIDADE) AS SGUNIDADE, RF.QTUNIDESTLO, RF.QTBRUTALO, RF.IDPRODBASELO, RF.CDAPRERECE, RF.DTULTATURECF, RF.VRPEFATNUTLO, RF.QTCALCNUTRLO, RF.QTBRUTALOUNR, RF.IDQTDEFIXLO, RF.IDTPREQPRODFILI, RF.QTCOMPLPRODFILI, RF.IDUTCOMPENTDIRF, RF.QTLIMSEGFILI, RF.NRORG, RF.VRPERCDEGELO FROM RECEFILI   RF INNER JOIN PRODUTO    P ON P.CDPRODUTO = RF.CDPRODUTO WHERE RF.CDFILIAL = :CDFILIAL AND RF.CDFILAUXPRAT = :CDFILAUXPRAT AND RF.CDPRATO = :CDPRATO ".$whereProdLine." ORDER BY P.CDARVPROD";
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function returnRecipeServico($cdprato, $cdFilAuxPrat, $cdfilial, $servico, $cdproduto = null) {
		$params = array(
			"CDPRATO"      => $cdprato,
			"CDFILAUXPRAT" => $cdFilAuxPrat,
			"CDFILIAL"     => $cdfilial,
			"CDSERVFILI"   => $servico
		);
		
		if (!empty($cdproduto)) {
      $whereProdLine = "AND RS.CDPRODUTO = :CDPRODUTO ";
      $params['CDPRODUTO'] = $cdproduto;
    } else $whereProdLine = "";
		
		$sql = "SELECT RS.CDFILAUXPRAT, RS.CDPRATO, RS.CDFILIAL, RS.CDSERVFILI, RS.CDPRODUTO, RS.QTPRODRECSER, RS.VRPEFATCOCSE, RS.VRPEFATCORSE, RS.HRTEMPPREPSE, NVL(RS.SGUNIDADE, P.SGUNIDADE) AS SGUNIDADE, RS.QTUNIDESTSE, RS.QTBRUTASE, RS.IDPRODBASESE, RS.CDAPRERECE, RS.DTULTATURECS, RS.VRPEFATNUTSE, RS.QTCALCNUTRSE, RS.QTBRUTASEUNR, RS.IDQTDEFIXSE, RS.IDTPREQPRODSERV, RS.QTCOMPLPRODSERV, RS.IDUTCOMPENTDIRS, RS.QTLIMSEGSERV, RS.NRORG, RS.VRPERCDEGELO FROM RECESERV RS INNER JOIN PRODUTO    P ON P.CDPRODUTO = RS.CDPRODUTO WHERE RS.CDPRATO = :CDPRATO AND RS.CDFILIAL = :CDFILIAL AND RS.CDFILAUXPRAT = :CDFILAUXPRAT AND RS.CDSERVFILI = :CDSERVFILI ".$whereProdLine." ORDER BY P.CDARVPROD";
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function returnRecipeTpCard($cdprato, $cdFilAuxPrat, $cardapio, $cdfilcentpme, $cdproduto = null) {
		$params = array(
			"CDPRATO"      => $cdprato,
			"CDFILAUXPRAT" => $cdFilAuxPrat,
			"CDTIPOCARD"   => $cardapio,
			"CDFILCENTPME" => $cdfilcentpme
		);

    if (!empty($cdproduto)) {
      $whereProdLine = "AND RT.CDPRODUTO = :CDPRODUTO ";
      $params['CDPRODUTO'] = $cdproduto;
    } else $whereProdLine = "";
		
		$sql = "SELECT RT.CDFILCENTPME, RT.CDTIPOCARD, RT.CDFILAUXPRAT, RT.CDPRATO, RT.CDPRODUTO, RT.QTPRODPRATTP, RT.VRPEFATCOCPRTP, RT.VRPEFATCORPRTP, RT.HRTEMPPREPPRTP, NVL(RT.SGUNIDADE, P.SGUNIDADE) AS SGUNIDADE, RT.QTUNIDESTPRTP, RT.QTBRUTAPRTP, RT.IDPRODBASEPRTP, RT.CDAPRERECE, RT.DTULTATURECPTP, RT.VRPEFATNUTPRTP, RT.QTCALCNUTRPRTP, RT.QTBRUTAPRUNRTP, RT.IDQTDEFIXPRTP, RT.NRORG, RT.VRPERCDEGELO FROM RECETPCARD   RT INNER JOIN PRODUTO      P ON P.CDPRODUTO = RT.CDPRODUTO WHERE RT.CDPRATO = :CDPRATO AND RT.CDTIPOCARD = :CDTIPOCARD AND RT.CDFILAUXPRAT = :CDFILAUXPRAT AND RT.CDFILCENTPME = :CDFILCENTPME ".$whereProdLine." ORDER BY P.CDARVPROD";
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function returnRecipePadrQual($cdprato, $cdFilAuxPrat, $nrPadrQual, $cdproduto = null) {
		$params = array(
			"CDPRATO"      => $cdprato,
			"CDFILAUXPRAT" => $cdFilAuxPrat,
			"NRPADRAOQUALIDADE"   => $nrPadrQual
		);

    if (!empty($cdproduto)) {
      $whereProdLine = "AND RPQ.CDPRODUTO = :CDPRODUTO ";
      $params['CDPRODUTO'] = $cdproduto;
    } else $whereProdLine = "";
		
		$sql = "SELECT RPQ.NRRECEPADQUALI, RPQ.CDFILAUXPRAT, RPQ.CDPRATO, RPQ.NRPADRAOQUALIDADE, RPQ.CDPRODUTO, RPQ.QTPRODRECPADQ, RPQ.VRPEFATCOCPADQ, RPQ.VRPEFATCORPADQ, NVL(RPQ.SGUNIDADE, P.SGUNIDADE) AS SGUNIDADE, RPQ.QTBRUTAPADQUNR, RPQ.IDPRODBASEPADQ, RPQ.IDQTDEFIXPADQ, RPQ.NRORG FROM RECEPADQUALI RPQ INNER JOIN PRODUTO P ON P.CDPRODUTO = RPQ.CDPRODUTO WHERE RPQ.NRPADRAOQUALIDADE = :NRPADRAOQUALIDADE AND RPQ.CDFILAUXPRAT = :CDFILAUXPRAT AND RPQ.CDPRATO = :CDPRATO ".$whereProdLine." ORDER BY P.CDARVPROD";
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function returnRecipeRegiao($cdprato, $cdFilAuxPrat, $nrPadrQual, $cdRegiao, $cdproduto = null) {
		$params = array(
			"CDPRATO"      => $cdprato,
			"CDFILAUXPRAT" => $cdFilAuxPrat,
			"NRPADRAOQUALIDADE"   => $nrPadrQual,
			"CDREGIAO" => $cdRegiao
		);

    if (!empty($cdproduto)) {
      $whereProdLine = "AND RR.CDPRODUTO = :CDPRODUTO ";
      $params['CDPRODUTO'] = $cdproduto;
    } else $whereProdLine = "";
		
		$sql = "SELECT RR.NRRECEREGIAO, RR.CDFILAUXPRAT, RR.CDPRATO, RR.CDREGIAO, RR.NRPADRAOQUALIDADE, RR.CDPRODUTO, RR.QTPRODRECREGIAO, RR.VRPEFATCOCREGIAO, RR.VRPEFATCORREGIAO, RR.SGUNIDADE, RR.QTBRUTAREGIAOUNR, RR.IDPRODBASEREGIAO, RR.IDQTDEFIXREGIAO, RR.NRORG FROM RECEREGIAO RR INNER JOIN PRODUTO P ON RR.CDPRODUTO = P.CDPRODUTO WHERE RR.NRPADRAOQUALIDADE = :NRPADRAOQUALIDADE AND RR.CDREGIAO = :CDREGIAO AND RR.CDFILAUXPRAT = :CDFILAUXPRAT AND RR.CDPRATO = :CDPRATO ".$whereProdLine." ORDER BY P.CDARVPROD";
		return $this->entityManager->getConnection()->fetchAll($sql, $params);
	}
	
	public function quantidadeIngredientes($row) {
        $whereLine = '';
        $params = array(
            "P_CDPRATO" => $row['CDPRATO'],
            "P_CDFILAUXPRAT" => $row['CDFILAUXPRAT']
        );
            
        if($row['RECIPEDEST'] == 'PADRAO') {
            $tabela = 'RECEPADR';
        } else if($row['RECIPEDEST'] == 'LOCAL') {
            $tabela = 'RECEFILI';
            $whereLine = 'AND CDFILIAL = :P_CDFILIAL';
            $params['P_CDFILIAL'] = $row['CDFILIAL'];
        } else if($row['RECIPEDEST'] == 'TIPOCARD') {
            $tabela = 'RECETPCARD';
            $whereLine = 'AND CDFILCENTPME = :P_CDFILCENTPME AND CDTIPOCARD = :P_CDTIPOCARD';
            $params['P_CDFILCENTPME'] = $row['CDFILCENTPME'];
            $params['P_CDTIPOCARD'] = $row['CDTIPOCARD'];
        } else {
            $tabela = 'RECESERV';
            $whereLine = 'AND CDFILIAL = :P_CDFILIAL AND CDSERVFILI = :P_CDSERVFILI';
            $params['P_CDFILIAL'] =  $row['CDFILIAL'];            
            $params['P_CDSERVFILI'] = $row['servfili'];
        }

        try {
            $sql = "SELECT COUNT(*) AS QTD_INGREDIENTES_TOTAIS
                    FROM $tabela 
                    WHERE CDPRATO = :P_CDPRATO
                    AND CDFILAUXPRAT = :P_CDFILAUXPRAT
                    $whereLine";
                    
            return $this->entityManager->getConnection()->fetchAssoc($sql, $params);
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function updateRecipeProduct($recipe, $dados) {
      $update = "";
      $params = array();
      switch($recipe) {
        case 'RECEPADR':
          $update = "UPDATE RECEPADR
                    SET
                        CDPRODUTO = :CDPRODUTOAUX
                    WHERE
                        CDFILAUXPRAT = :CDFILAUXPRAT
                        AND CDPRATO = :CDPRATO
                        AND CDPRODUTO = :CDPRODUTO";
                        
          $params = array(
            "CDPRODUTOAUX" => $dados['CDPRODUTO_NEW'],
            "CDFILAUXPRAT" => $dados['CDFILAUXPRAT'],
            "CDPRATO" => $dados['CDPRATO'],
            "CDPRODUTO" => $dados['CDPRODUTO_OLD'],
          );
          break;
        case 'RECEFILI':
          $update = "UPDATE RECEFILI
                    SET
                        CDPRODUTO = :CDPRODUTOAUX
                    WHERE
                        CDFILAUXPRAT = :CDFILAUXPRAT
                        AND CDPRATO = :CDPRATO
                        AND CDFILIAL = :CDFILIAL
                        AND CDPRODUTO = :CDPRODUTO";
          $params = array(
            "CDPRODUTOAUX" => $dados['CDPRODUTO_NEW'],
            "CDFILAUXPRAT" => $dados['CDFILAUXPRAT'],
            "CDPRATO" => $dados['CDPRATO'],
            "CDPRODUTO" => $dados['CDPRODUTO_OLD'],
            "CDFILIAL" => $dados['CDFILIAL'],
          );
          break;
        case 'RECESERV':
          $update = "UPDATE RECESERV
                    SET
                        CDPRODUTO = :CDPRODUTOAUX
                    WHERE
                        CDFILAUXPRAT = :CDFILAUXPRAT
                        AND CDPRATO = :CDPRATO
                        AND CDFILIAL = :CDFILIAL
                        AND CDPRODUTO = :CDPRODUTO
                        AND CDSERVFILI = :CDSERVFILI";
          $params = array(
            "CDPRODUTOAUX" => $dados['CDPRODUTO_NEW'],
            "CDFILAUXPRAT" => $dados['CDFILAUXPRAT'],
            "CDPRATO" => $dados['CDPRATO'],
            "CDPRODUTO" => $dados['CDPRODUTO_OLD'],
            "CDFILIAL" => $dados['CDFILIAL'],
            "CDSERVFILI" => $dados['CDSERVFILI'],
          );
          break;
        case 'RECETPCARD':
          $update = "UPDATE RECETPCARD
                    SET
                        CDPRODUTO = :CDPRODUTOAUX
                    WHERE
                        CDFILAUXPRAT = :CDFILAUXPRAT
                        AND CDPRATO = :CDPRATO
                        AND CDTIPOCARD = :CDTIPOCARD
                        AND CDPRODUTO = :CDPRODUTO
                        AND CDFILCENTPME = :CDFILCENTPME";
          $params = array(
            "CDPRODUTOAUX" => $dados['CDPRODUTO_NEW'],
            "CDFILAUXPRAT" => $dados['CDFILAUXPRAT'],
            "CDPRATO" => $dados['CDPRATO'],
            "CDPRODUTO" => $dados['CDPRODUTO_OLD'],
            "CDTIPOCARD" => $dados['CDTIPOCARD'],
            "CDFILCENTPME" => $dados['CDFILCENTPME'],
          );
          break;
      }
      $stmt = $this->entityManager->getConnection()->prepare($update);
      $stmt->execute($params);
    }
    
  public function deleteRecipeProducts(DTO\Request\Row $request, DTO\Response $response) {
    	$this->connection->beginTransaction();
    	try {
	    	$parameters = $request->getParameters();
	    	$rows = $parameters['selectedRows'];
	    	$itemNaoExcluido = 0;
	    	
	    	foreach($rows as $row) {
	    		$prato = $row['CDPRATO'];
	            $dados = array(
	                "CDPRATO"      => $prato,
	                "CDFILAUXPRAT" => $row['CDFILAUXPRAT'],
	                "CDFILIAL"     => $row['FILIAL'],
	                "CDPRODUTO"    => $row['CDPRODUTO'],
	                "CDSERVFILI"   => $row['CDSERVFILI'],
	                "CDFILCENTPME" => $row['CDFILCENTPME'],
	                "CDTIPOCARD"   => $row['CDTIPOCARD']
	            );
	            
	            if ($row['CDFILAUXPRAT'] == 'P') {
	            	
	            	if ($row['FILIAL'] == 'P') { //valida itens da receita padrão
	            		$dados['RECIPEDEST'] = 'PADRAO';
                    	$result = $this->quantidadeIngredientes($dados);
                    	
                    	if ($result["QTD_INGREDIENTES_TOTAIS"] > $parameters['PADRAO'][$prato]) { //exclui o item
	                        $this->deleteRecipe($dados, true);
	                        $parameters['PADRAO'][$prato]--;
	                    } else {
	                        $itemNaoExcluido++;
	                    }
	            	} else { //receitas em geral
	                    if ($row['CDSERVFILI'] != null) {
	                        $dados['RECIPEDEST'] = 'SERVICO';
	                    } else if ($row['CDTIPOCARD'] != null) {
	                    	$dados['RECIPEDEST'] = 'TIPOCARD';
	                    } else $dados['RECIPEDEST'] = 'LOCAL';
	                    $this->deleteRecipe($dados, true);
	                }
	            } else {
	                if ($row['CDSERVFILI'] != null) { //valida itens da receita local
	                    $dados['RECIPEDEST'] = 'SERVICO';    
	                    $this->deleteRecipe($dados, true);
	                } else if ($row['CDTIPOCARD'] != null) {
	                	$dados['RECIPEDEST'] = 'TIPOCARD';    
	                    $this->deleteRecipe($dados, true);
	                } else {
	                    $dados['RECIPEDEST'] = 'LOCAL';
	                    $result = $this->quantidadeIngredientes($dados);
	                    
	                    if($result["QTD_INGREDIENTES_TOTAIS"] > $parameters['LOCAL'][$prato]){//exclui o item
	                        $parameters['LOCAL'][$prato]--;
	                    }else{
	                        $itemNaoExcluido++;
	                    }                
	                }
	            }  
	    	}
	    	
	    	$resposta['mensagem'] = $itemNaoExcluido;
	    	$this->connection->commit();
	        $response->addDataset(new DataSet('MENSAGEM', array($resposta)));
    	} catch (\Exception $e) {
    		$this->connection->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}